/********************************************************************************
** Form generated from reading UI file 'jsoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JSOPTIONS_H
#define UI_JSOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_JsOptions
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QVBoxLayout *verticalLayout;
    QCheckBox *jscanOpenWindow;
    QCheckBox *jscanActivateWindow;
    QCheckBox *jscanAccessClipboard;
    QCheckBox *jscanPaste;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *jsoptsbbox;

    void setupUi(QDialog *JsOptions)
    {
        if (JsOptions->objectName().isEmpty())
            JsOptions->setObjectName("JsOptions");
        JsOptions->resize(268, 222);
        verticalLayout_2 = new QVBoxLayout(JsOptions);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(JsOptions);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        jscanOpenWindow = new QCheckBox(JsOptions);
        jscanOpenWindow->setObjectName("jscanOpenWindow");

        verticalLayout->addWidget(jscanOpenWindow);

        jscanActivateWindow = new QCheckBox(JsOptions);
        jscanActivateWindow->setObjectName("jscanActivateWindow");

        verticalLayout->addWidget(jscanActivateWindow);

        jscanAccessClipboard = new QCheckBox(JsOptions);
        jscanAccessClipboard->setObjectName("jscanAccessClipboard");

        verticalLayout->addWidget(jscanAccessClipboard);

        jscanPaste = new QCheckBox(JsOptions);
        jscanPaste->setObjectName("jscanPaste");

        verticalLayout->addWidget(jscanPaste);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        verticalLayout_2->addLayout(verticalLayout);

        jsoptsbbox = new QDialogButtonBox(JsOptions);
        jsoptsbbox->setObjectName("jsoptsbbox");
        jsoptsbbox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(jsoptsbbox);


        retranslateUi(JsOptions);
        QObject::connect(jsoptsbbox, &QDialogButtonBox::accepted, JsOptions, qOverload<>(&QDialog::accept));
        QObject::connect(jsoptsbbox, &QDialogButtonBox::rejected, JsOptions, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(JsOptions);
    } // setupUi

    void retranslateUi(QDialog *JsOptions)
    {
        JsOptions->setWindowTitle(QCoreApplication::translate("JsOptions", "JavaScript Options", nullptr));
        label->setText(QCoreApplication::translate("JsOptions", "Allow JavaScript to:", nullptr));
        jscanOpenWindow->setText(QCoreApplication::translate("JsOptions", "Open popup windows", nullptr));
        jscanActivateWindow->setText(QCoreApplication::translate("JsOptions", "Activate windows", nullptr));
        jscanAccessClipboard->setText(QCoreApplication::translate("JsOptions", "Access clipboard", nullptr));
        jscanPaste->setText(QCoreApplication::translate("JsOptions", "Paste from clipboard", nullptr));
    } // retranslateUi

};

namespace Ui {
    class JsOptions: public Ui_JsOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_JSOPTIONS_H
