/****************************************************************************
** Meta object code from reading C++ file 'toolbutton.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.07.80/src/lib/tools/toolbutton.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'toolbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ToolButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto ToolButton::qt_create_metaobjectdata<qt_meta_tag_ZN10ToolButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ToolButton",
        "middleMouseClicked",
        "",
        "controlClicked",
        "doubleClicked",
        "aboutToShowMenu",
        "aboutToHideMenu",
        "menuAboutToHide",
        "showMenu",
        "fixedsize",
        "QSize",
        "fixedwidth",
        "fixedheight",
        "multiIcon",
        "QImage",
        "icon",
        "QIcon",
        "themeIcon",
        "fallbackIcon"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'middleMouseClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controlClicked'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToShowMenu'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToHideMenu'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'menuAboutToHide'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMenu'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fixedsize'
        QtMocHelpers::PropertyData<QSize>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'fixedwidth'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'fixedheight'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'multiIcon'
        QtMocHelpers::PropertyData<QImage>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'icon'
        QtMocHelpers::PropertyData<QIcon>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'themeIcon'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'fallbackIcon'
        QtMocHelpers::PropertyData<QIcon>(18, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ToolButton, qt_meta_tag_ZN10ToolButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ToolButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QToolButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ToolButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ToolButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ToolButtonE_t>.metaTypes,
    nullptr
} };

void ToolButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ToolButton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->middleMouseClicked(); break;
        case 1: _t->controlClicked(); break;
        case 2: _t->doubleClicked(); break;
        case 3: _t->aboutToShowMenu(); break;
        case 4: _t->aboutToHideMenu(); break;
        case 5: _t->menuAboutToHide(); break;
        case 6: _t->showMenu(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ToolButton::*)()>(_a, &ToolButton::middleMouseClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolButton::*)()>(_a, &ToolButton::controlClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolButton::*)()>(_a, &ToolButton::doubleClicked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolButton::*)()>(_a, &ToolButton::aboutToShowMenu, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolButton::*)()>(_a, &ToolButton::aboutToHideMenu, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSize*>(_v) = _t->size(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 3: *reinterpret_cast<QImage*>(_v) = _t->multiIcon(); break;
        case 4: *reinterpret_cast<QIcon*>(_v) = _t->icon(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->themeIcon(); break;
        case 6: *reinterpret_cast<QIcon*>(_v) = _t->fallbackIcon(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFixedSize(*reinterpret_cast<QSize*>(_v)); break;
        case 1: _t->setFixedWidth(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setFixedHeight(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setMultiIcon(*reinterpret_cast<QImage*>(_v)); break;
        case 4: _t->setIcon(*reinterpret_cast<QIcon*>(_v)); break;
        case 5: _t->setThemeIcon(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFallbackIcon(*reinterpret_cast<QIcon*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ToolButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ToolButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ToolButtonE_t>.strings))
        return static_cast<void*>(this);
    return QToolButton::qt_metacast(_clname);
}

int ToolButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QToolButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ToolButton::middleMouseClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ToolButton::controlClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ToolButton::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ToolButton::aboutToShowMenu()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ToolButton::aboutToHideMenu()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
