/********************************************************************************
** Form generated from reading UI file 'historysidebar.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HISTORYSIDEBAR_H
#define UI_HISTORYSIDEBAR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "historytreeview.h"

QT_BEGIN_NAMESPACE

class Ui_HistorySideBar
{
public:
    QVBoxLayout *verticalLayout;
    QLineEdit *search;
    HistoryTreeView *historyTree;

    void setupUi(QWidget *HistorySideBar)
    {
        if (HistorySideBar->objectName().isEmpty())
            HistorySideBar->setObjectName("HistorySideBar");
        HistorySideBar->resize(150, 457);
        verticalLayout = new QVBoxLayout(HistorySideBar);
        verticalLayout->setSpacing(1);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 2, 0, 0);
        search = new QLineEdit(HistorySideBar);
        search->setObjectName("search");

        verticalLayout->addWidget(search);

        historyTree = new HistoryTreeView(HistorySideBar);
        historyTree->setObjectName("historyTree");
        historyTree->setAlternatingRowColors(true);
        historyTree->setHeaderHidden(true);

        verticalLayout->addWidget(historyTree);


        retranslateUi(HistorySideBar);

        QMetaObject::connectSlotsByName(HistorySideBar);
    } // setupUi

    void retranslateUi(QWidget *HistorySideBar)
    {
        search->setPlaceholderText(QCoreApplication::translate("HistorySideBar", "Search...", nullptr));
        (void)HistorySideBar;
    } // retranslateUi

};

namespace Ui {
    class HistorySideBar: public Ui_HistorySideBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HISTORYSIDEBAR_H
