/********************************************************************************
** Form generated from reading UI file 'bookmarksmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOOKMARKSMANAGER_H
#define UI_BOOKMARKSMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "bookmarkstreeview.h"

QT_BEGIN_NAMESPACE

class Ui_BookmarksManager
{
public:
    QVBoxLayout *verticalLayout;
    BookmarksTreeView *tree;
    QGroupBox *editBox;
    QFormLayout *formLayout_2;
    QLabel *labelTitle;
    QLineEdit *title;
    QLabel *labelAddress;
    QLineEdit *address;
    QLabel *labelKeyword;
    QLineEdit *keyword;
    QLabel *labelDescription;
    QPlainTextEdit *description;

    void setupUi(QWidget *BookmarksManager)
    {
        if (BookmarksManager->objectName().isEmpty())
            BookmarksManager->setObjectName("BookmarksManager");
        BookmarksManager->resize(689, 467);
        verticalLayout = new QVBoxLayout(BookmarksManager);
        verticalLayout->setObjectName("verticalLayout");
        tree = new BookmarksTreeView(BookmarksManager);
        tree->setObjectName("tree");

        verticalLayout->addWidget(tree);

        editBox = new QGroupBox(BookmarksManager);
        editBox->setObjectName("editBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(editBox->sizePolicy().hasHeightForWidth());
        editBox->setSizePolicy(sizePolicy);
        formLayout_2 = new QFormLayout(editBox);
        formLayout_2->setObjectName("formLayout_2");
        labelTitle = new QLabel(editBox);
        labelTitle->setObjectName("labelTitle");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, labelTitle);

        title = new QLineEdit(editBox);
        title->setObjectName("title");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, title);

        labelAddress = new QLabel(editBox);
        labelAddress->setObjectName("labelAddress");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, labelAddress);

        address = new QLineEdit(editBox);
        address->setObjectName("address");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, address);

        labelKeyword = new QLabel(editBox);
        labelKeyword->setObjectName("labelKeyword");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, labelKeyword);

        keyword = new QLineEdit(editBox);
        keyword->setObjectName("keyword");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, keyword);

        labelDescription = new QLabel(editBox);
        labelDescription->setObjectName("labelDescription");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, labelDescription);

        description = new QPlainTextEdit(editBox);
        description->setObjectName("description");
        description->setMinimumSize(QSize(0, 50));
        description->setMaximumSize(QSize(16777215, 50));

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, description);


        verticalLayout->addWidget(editBox);


        retranslateUi(BookmarksManager);

        QMetaObject::connectSlotsByName(BookmarksManager);
    } // setupUi

    void retranslateUi(QWidget *BookmarksManager)
    {
        BookmarksManager->setWindowTitle(QCoreApplication::translate("BookmarksManager", "Bookmarks", nullptr));
        labelTitle->setText(QCoreApplication::translate("BookmarksManager", "Title:", nullptr));
        labelAddress->setText(QCoreApplication::translate("BookmarksManager", "Address:", nullptr));
        labelKeyword->setText(QCoreApplication::translate("BookmarksManager", "Keyword:", nullptr));
        labelDescription->setText(QCoreApplication::translate("BookmarksManager", "Description", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BookmarksManager: public Ui_BookmarksManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BOOKMARKSMANAGER_H
