/********************************************************************************
** Form generated from reading UI file 'preferences.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCES_H
#define UI_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mactoolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_Preferences
{
public:
    QGridLayout *gridLayout_5;
    QDialogButtonBox *buttonBox;
    QListWidget *listWidget;
    QLabel *caption;
    QFrame *line;
    QFrame *line_2;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_4;
    QStackedWidget *stackedWidget;
    QWidget *generalPage;
    QGridLayout *gridLayout_6;
    QFrame *newTabFrame;
    QHBoxLayout *horizontalLayout_3;
    QLineEdit *newTabUrl;
    MacToolButton *newTabUseCurrent;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *cannotDeleteActiveProfileLabel;
    QPushButton *createProfile;
    QPushButton *deleteProfile;
    QSpacerItem *horizontalSpacer_7;
    QLabel *label_24;
    QComboBox *startProfile;
    QLabel *label_3;
    QComboBox *afterLaunch;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *homepage;
    MacToolButton *useCurrentBut;
    QLabel *label_2;
    QComboBox *newTab;
    QLabel *label_4;
    QLabel *label_5;
    QCheckBox *checkUpdates;
    QLabel *label_45;
    QLabel *activeProfile;
    QCheckBox *dontLoadTabsUntilSelected;
    QSpacerItem *verticalSpacer_6;
    QHBoxLayout *hLayoutDefaultBrowser;
    QCheckBox *checkDefaultBrowser;
    QPushButton *checkNowDefaultBrowser;
    QSpacerItem *hSpacerDefaultBrowser;
    QWidget *appearancePage;
    QGridLayout *gridLayout_21;
    QTabWidget *tabWidget_2;
    QWidget *tab_5;
    QGridLayout *gridLayout_22;
    QWidget *themesWidget;
    QWidget *tab_4;
    QGridLayout *gridLayout_16;
    QGridLayout *gridLayout_7;
    QCheckBox *showBookmarksToolbar;
    QLabel *label_56;
    QCheckBox *showStatusbar;
    QCheckBox *showNavigationToolbar;
    QCheckBox *instantBookmarksToolbar;
    QSpinBox *defaultSideBarWidth;
    QCheckBox *showProfileName;
    QLabel *label_17;
    QSpacerItem *verticalSpacer_12;
    QGridLayout *gridLayout_25;
    MacToolButton *backgroundColorLoading;
    QToolButton *backgroundColorLoadingReset;
    MacToolButton *backgroundColorLoaded;
    QToolButton *backgroundColorLoadedReset;
    QLabel *label_49;
    QLabel *label_21;
    QSpinBox *loadedSwitchDelay;
    QLabel *label_55;
    QLabel *label_18;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer_8;
    QWidget *tabsPage;
    QGridLayout *gridLayout_2;
    QTabWidget *tabWidget_3;
    QWidget *tabsBehaviourPage;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *hideTabsOnTab;
    QCheckBox *activateLastTab;
    QCheckBox *openNewTabAfterActive;
    QCheckBox *openNewEmptyTabAfterActive;
    QCheckBox *openPopupsInTabs;
    QCheckBox *blockAutomaticPopups;
    QCheckBox *alwaysSwitchTabsWithWheel;
    QCheckBox *switchToNewTabs;
    QCheckBox *dontCloseOnLastTab;
    QCheckBox *askWhenClosingMultipleTabs;
    QCheckBox *showClosedTabsButton;
    QHBoxLayout *horizontalLayout_21;
    QLabel *label_65;
    QComboBox *showCloseOnInactive;
    QSpacerItem *horizontalSpacer_30;
    QSpacerItem *verticalSpacer_8;
    QWidget *addressBarBehaviourPage;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_16;
    QLabel *label_59;
    QComboBox *addressbarCompletion;
    QSpacerItem *horizontalSpacer_23;
    QCheckBox *useInlineCompletion;
    QCheckBox *completionShowSwitchTab;
    QCheckBox *alwaysShowGoIcon;
    QCheckBox *showZoomLabel;
    QCheckBox *selectAllOnFocus;
    QCheckBox *selectAllOnClick;
    QCheckBox *searchFromAddressBar;
    QCheckBox *searchWithDefaultEngine;
    QCheckBox *showABSearchSuggestions;
    QCheckBox *completionPopupExpandToWindow;
    QSpacerItem *verticalSpacer_16;
    QCheckBox *showLoadingInAddressBar;
    QWidget *addressProgressSettings;
    QHBoxLayout *horizontalLayout_18;
    QSpacerItem *horizontalSpacer;
    QComboBox *progressStyleSelector;
    QCheckBox *checkBoxCustomProgressColor;
    QWidget *progressBarColorSelector;
    QHBoxLayout *horizontalLayout_19;
    MacToolButton *customColorToolButton;
    MacToolButton *resetProgressBarcolor;
    QSpacerItem *horizontalSpacer_9;
    QSpacerItem *verticalSpacer_7;
    QWidget *browsingPage;
    QGridLayout *gridLayout_9;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_18;
    QVBoxLayout *verticalLayout;
    QCheckBox *allowPlugins;
    QCheckBox *intPDFViewer;
    QCheckBox *allowJavaScript;
    QCheckBox *linksInFocusChain;
    QCheckBox *printEBackground;
    QCheckBox *animateScrolling;
    QCheckBox *spatialNavigation;
    QCheckBox *useNativeScrollbars;
    QCheckBox *disableVideoAutoPlay;
    QCheckBox *webRTCPublicIpOnly;
    QCheckBox *dnsPrefetch;
    QCheckBox *screenCaptureEnabled;
    QCheckBox *hardwareAccel;
    QCheckBox *readingFromCanvasEnabled;
    QCheckBox *forceDarkMode;
    QCheckBox *allowImageAnimation;
    QHBoxLayout *horizontalLayout_22;
    QLabel *label_16;
    QComboBox *prefferColorScheme;
    QSpacerItem *horizontalSpacer_40;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_14;
    QSpinBox *wheelScroll;
    QLabel *label_26;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_44;
    QComboBox *defaultZoomLevel;
    QSpacerItem *horizontalSpacer_12;
    QSpacerItem *verticalSpacer_9;
    QWidget *tab_2;
    QGridLayout *gridLayout_19;
    QGridLayout *gridLayout_4;
    QCheckBox *allowCache;
    QSpacerItem *horizontalSpacer_33;
    QCheckBox *removeCache;
    QLabel *maxCacheLabel;
    QSpinBox *cacheMB;
    QLabel *storeCacheLabel;
    QHBoxLayout *horizontalLayout_20;
    QLineEdit *cachePath;
    MacToolButton *changeCachePath;
    QGridLayout *gridLayout_3;
    QCheckBox *saveHistory;
    QCheckBox *deleteHistoryOnClose;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *html5storage;
    QCheckBox *deleteHtml5storageOnClose;
    QSpacerItem *horizontalSpacer_21;
    QPushButton *deleteHtml5storage;
    QSpacerItem *verticalSpacer_11;
    QSpacerItem *verticalSpacer;
    QWidget *tab_3;
    QGridLayout *gridLayout_8;
    QSpacerItem *verticalSpacer_14;
    QRadioButton *systemProxy;
    QSpacerItem *horizontalSpacer_29;
    QRadioButton *manualProxy;
    QHBoxLayout *horizontalLayout_9;
    QComboBox *proxyType;
    QLineEdit *proxyServer;
    QLabel *label_37;
    QLineEdit *proxyPort;
    QHBoxLayout *horizontalLayout_23;
    QLabel *label_38;
    QLineEdit *proxyUsername;
    QLabel *label_39;
    QLineEdit *proxyPassword;
    QSpacerItem *horizontalSpacer_3;
    QRadioButton *noProxy;
    QWidget *fontsPage;
    QGridLayout *gridLayout_15;
    QLabel *label_27;
    QLabel *label_6;
    QLabel *label_28;
    QFontComboBox *fontFixed;
    QLabel *label_29;
    QFontComboBox *fontSerif;
    QLabel *label_30;
    QFontComboBox *fontSansSerif;
    QLabel *label_31;
    QFontComboBox *fontCursive;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *horizontalSpacer_11;
    QFontComboBox *fontStandard;
    QFontComboBox *fontFantasy;
    QLabel *label_34;
    QLabel *label_35;
    QFormLayout *formLayout;
    QLabel *label_33;
    QLabel *label_32;
    QSpinBox *sizeDefault;
    QSpinBox *sizeFixed;
    QLabel *label_46;
    QLabel *label_47;
    QSpinBox *sizeMinimum;
    QSpinBox *sizeMinimumLogical;
    QWidget *shortcutsPage;
    QGridLayout *gridLayout;
    QLabel *label_13;
    QCheckBox *switchTabsAlt;
    QCheckBox *loadSpeedDialsCtrl;
    QCheckBox *singleKeyShortcuts;
    QCheckBox *closeAppWithCtrlQ;
    QSpacerItem *verticalSpacer_13;
    QWidget *downloadsPage;
    QGridLayout *gridLayout_10;
    QLabel *label_23;
    QRadioButton *askEverytime;
    QRadioButton *useDefined;
    QHBoxLayout *horizontalLayout_4;
    QLineEdit *downLoc;
    MacToolButton *downButt;
    QSpacerItem *horizontalSpacer_18;
    QSpacerItem *horizontalSpacer_19;
    QLabel *label_22;
    QCheckBox *closeDownManOnFinish;
    QLabel *label_51;
    QCheckBox *useExternalDownManager;
    QFormLayout *formLayout_2;
    QLabel *label_52;
    QLabel *label_53;
    QLineEdit *externalDownArguments;
    QHBoxLayout *horizontalLayout_7;
    QLineEdit *externalDownExecutable;
    MacToolButton *chooseExternalDown;
    QLabel *label_64;
    QSpacerItem *verticalSpacer_10;
    QWidget *passwordManagerPage;
    QGridLayout *gridLayout_11;
    QLabel *label_20;
    QCheckBox *allowPassManager;
    QSpacerItem *horizontalSpacer_14;
    QSpacerItem *horizontalSpacer_15;
    QFrame *AutoFillFrame;
    QHBoxLayout *autoFillFrame;
    QCheckBox *autoCompletePasswords;
    QWidget *privacyPage;
    QGridLayout *gridLayout_12;
    QTabWidget *tabWidget_4;
    QWidget *tab_9;
    QGridLayout *gridLayout_24;
    QLabel *label_19;
    QPushButton *cookieManagerBut;
    QSpacerItem *horizontalSpacer_22;
    QLabel *label_61;
    QPushButton *jsOptionsButton;
    QCheckBox *doNotTrack;
    QLabel *label_12;
    QSpacerItem *horizontalSpacer_20;
    QLabel *label_25;
    QLabel *label_50;
    QSpacerItem *verticalSpacer_3;
    QWidget *tab_10;
    QVBoxLayout *verticalLayout_7;
    QListWidget *siteSettingsHtml5List;
    QWidget *tab_11;
    QVBoxLayout *verticalLayout_6;
    QListWidget *siteSettingsList;
    QWidget *notificationsPage;
    QGridLayout *gridLayout_17;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout_10;
    QLabel *label_42;
    QSpinBox *notificationTimeout;
    QSpacerItem *horizontalSpacer_17;
    QLabel *label_41;
    QSpacerItem *verticalSpacer_4;
    QRadioButton *useNativeSystemNotifications;
    QRadioButton *doNotUseNotifications;
    QSpacerItem *horizontalSpacer_13;
    QLabel *label_43;
    QSpacerItem *verticalSpacer_5;
    QRadioButton *useOSDNotifications;
    QPushButton *notificationPreview;
    QSpacerItem *horizontalSpacer_27;
    QWidget *extensionsPage;
    QGridLayout *gridLayout_14;
    QFrame *horizontalFrame;
    QHBoxLayout *pluginsFrame;
    QWidget *spellcheckPage;
    QGridLayout *gridLayout_20;
    QSpacerItem *verticalSpacer_18;
    QSpacerItem *horizontalSpacer_16;
    QListWidget *spellcheckLanguages;
    QLabel *label_40;
    QScrollArea *spellcheckDirectoriesScrollArea;
    QWidget *scrollAreaWidgetContents_2;
    QHBoxLayout *horizontalLayout_14;
    QLabel *spellcheckDirectories;
    QLabel *label_48;
    QLabel *spellcheckNoLanguages;
    QLabel *label_10;
    QCheckBox *spellcheckEnabled;
    QWidget *otherPage;
    QGridLayout *gridLayout_13;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_28;
    QPushButton *protocolHandlers;
    QSpacerItem *horizontalSpacer_34;
    QLabel *label_54;
    QLabel *label_11;
    QLabel *label_60;
    QLabel *label_66;
    QLabel *label_36;
    QLabel *label_9;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_13;
    QSpacerItem *horizontalSpacer_37;
    QLineEdit *userStyleSheet;
    MacToolButton *chooseUserStylesheet;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer_35;
    QPushButton *certificateManager;
    QSpacerItem *horizontalSpacer_36;
    QHBoxLayout *horizontalLayout_17;
    QSpacerItem *horizontalSpacer_26;
    QPushButton *uaManager;
    QSpacerItem *horizontalSpacer_25;
    QSpacerItem *horizontalSpacer_6;
    QLabel *label_15;
    QHBoxLayout *horizontalLayout_15;
    QSpacerItem *horizontalSpacer_38;
    QPushButton *customSchemes;
    QSpacerItem *horizontalSpacer_39;
    QHBoxLayout *horizontalLayout_25;
    QSpacerItem *horizontalSpacer_31;
    QPushButton *searchEngines;
    QSpacerItem *horizontalSpacer_32;
    QHBoxLayout *horizontalLayout_8;
    QSpacerItem *horizontalSpacer_24;
    QPushButton *preferredLanguages;
    QSpacerItem *horizontalSpacer_10;
    QSpacerItem *verticalSpacer_15;
    QLabel *label_8;
    QHBoxLayout *horizontalLayout_24;
    QSpacerItem *horizontalSpacer_41;
    QPushButton *AutoOpenProtocolsButton;
    QSpacerItem *horizontalSpacer_42;

    void setupUi(QDialog *Preferences)
    {
        if (Preferences->objectName().isEmpty())
            Preferences->setObjectName("Preferences");
        Preferences->resize(1035, 727);
        gridLayout_5 = new QGridLayout(Preferences);
        gridLayout_5->setObjectName("gridLayout_5");
        buttonBox = new QDialogButtonBox(Preferences);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Apply|QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout_5->addWidget(buttonBox, 4, 2, 1, 1);

        listWidget = new QListWidget(Preferences);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        listWidget->setObjectName("listWidget");
        listWidget->setMinimumSize(QSize(220, 0));
        listWidget->setMaximumSize(QSize(220, 16777215));
        listWidget->setProperty("showDropIndicator", QVariant(false));
        listWidget->setIconSize(QSize(32, 32));
        listWidget->setVerticalScrollMode(QAbstractItemView::ScrollMode::ScrollPerPixel);
        listWidget->setMovement(QListView::Movement::Static);
        listWidget->setSpacing(2);
        listWidget->setUniformItemSizes(true);
        listWidget->setWordWrap(true);
        listWidget->setSelectionRectVisible(false);

        gridLayout_5->addWidget(listWidget, 0, 0, 5, 1);

        caption = new QLabel(Preferences);
        caption->setObjectName("caption");

        gridLayout_5->addWidget(caption, 0, 1, 1, 1);

        line = new QFrame(Preferences);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_5->addWidget(line, 1, 1, 1, 2);

        line_2 = new QFrame(Preferences);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_5->addWidget(line_2, 3, 1, 1, 2);

        scrollArea = new QScrollArea(Preferences);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 783, 727));
        verticalLayout_4 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        stackedWidget = new QStackedWidget(scrollAreaWidgetContents);
        stackedWidget->setObjectName("stackedWidget");
        stackedWidget->setFocusPolicy(Qt::FocusPolicy::NoFocus);
        generalPage = new QWidget();
        generalPage->setObjectName("generalPage");
        gridLayout_6 = new QGridLayout(generalPage);
        gridLayout_6->setObjectName("gridLayout_6");
        newTabFrame = new QFrame(generalPage);
        newTabFrame->setObjectName("newTabFrame");
        horizontalLayout_3 = new QHBoxLayout(newTabFrame);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        newTabUrl = new QLineEdit(newTabFrame);
        newTabUrl->setObjectName("newTabUrl");
        newTabUrl->setInputMethodHints(Qt::InputMethodHint::ImhNoAutoUppercase|Qt::InputMethodHint::ImhUrlCharactersOnly);

        horizontalLayout_3->addWidget(newTabUrl);

        newTabUseCurrent = new MacToolButton(newTabFrame);
        newTabUseCurrent->setObjectName("newTabUseCurrent");

        horizontalLayout_3->addWidget(newTabUseCurrent);


        gridLayout_6->addWidget(newTabFrame, 4, 2, 1, 1);

        frame = new QFrame(generalPage);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 20, 0);
        cannotDeleteActiveProfileLabel = new QLabel(frame);
        cannotDeleteActiveProfileLabel->setObjectName("cannotDeleteActiveProfileLabel");
        cannotDeleteActiveProfileLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(cannotDeleteActiveProfileLabel);

        createProfile = new QPushButton(frame);
        createProfile->setObjectName("createProfile");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(createProfile->sizePolicy().hasHeightForWidth());
        createProfile->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(createProfile);

        deleteProfile = new QPushButton(frame);
        deleteProfile->setObjectName("deleteProfile");
        deleteProfile->setEnabled(false);
        sizePolicy.setHeightForWidth(deleteProfile->sizePolicy().hasHeightForWidth());
        deleteProfile->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(deleteProfile);


        gridLayout_6->addWidget(frame, 12, 1, 1, 3);

        horizontalSpacer_7 = new QSpacerItem(20, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_7, 1, 0, 1, 1);

        label_24 = new QLabel(generalPage);
        label_24->setObjectName("label_24");

        gridLayout_6->addWidget(label_24, 0, 0, 1, 2);

        startProfile = new QComboBox(generalPage);
        startProfile->setObjectName("startProfile");

        gridLayout_6->addWidget(startProfile, 11, 2, 1, 1);

        label_3 = new QLabel(generalPage);
        label_3->setObjectName("label_3");

        gridLayout_6->addWidget(label_3, 1, 1, 1, 1);

        afterLaunch = new QComboBox(generalPage);
        afterLaunch->addItem(QString());
        afterLaunch->addItem(QString());
        afterLaunch->addItem(QString());
        afterLaunch->addItem(QString());
        afterLaunch->addItem(QString());
        afterLaunch->setObjectName("afterLaunch");

        gridLayout_6->addWidget(afterLaunch, 1, 2, 1, 1);

        label = new QLabel(generalPage);
        label->setObjectName("label");

        gridLayout_6->addWidget(label, 2, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        homepage = new QLineEdit(generalPage);
        homepage->setObjectName("homepage");
        homepage->setInputMethodHints(Qt::InputMethodHint::ImhNoAutoUppercase|Qt::InputMethodHint::ImhUrlCharactersOnly);

        horizontalLayout_2->addWidget(homepage);

        useCurrentBut = new MacToolButton(generalPage);
        useCurrentBut->setObjectName("useCurrentBut");

        horizontalLayout_2->addWidget(useCurrentBut);


        gridLayout_6->addLayout(horizontalLayout_2, 2, 2, 1, 1);

        label_2 = new QLabel(generalPage);
        label_2->setObjectName("label_2");

        gridLayout_6->addWidget(label_2, 3, 1, 1, 1);

        newTab = new QComboBox(generalPage);
        newTab->addItem(QString());
        newTab->addItem(QString());
        newTab->addItem(QString());
        newTab->addItem(QString());
        newTab->setObjectName("newTab");

        gridLayout_6->addWidget(newTab, 3, 2, 1, 1);

        label_4 = new QLabel(generalPage);
        label_4->setObjectName("label_4");

        gridLayout_6->addWidget(label_4, 9, 0, 1, 2);

        label_5 = new QLabel(generalPage);
        label_5->setObjectName("label_5");

        gridLayout_6->addWidget(label_5, 11, 1, 1, 1);

        checkUpdates = new QCheckBox(generalPage);
        checkUpdates->setObjectName("checkUpdates");

        gridLayout_6->addWidget(checkUpdates, 6, 1, 1, 2);

        label_45 = new QLabel(generalPage);
        label_45->setObjectName("label_45");

        gridLayout_6->addWidget(label_45, 10, 1, 1, 1);

        activeProfile = new QLabel(generalPage);
        activeProfile->setObjectName("activeProfile");

        gridLayout_6->addWidget(activeProfile, 10, 2, 1, 1);

        dontLoadTabsUntilSelected = new QCheckBox(generalPage);
        dontLoadTabsUntilSelected->setObjectName("dontLoadTabsUntilSelected");

        gridLayout_6->addWidget(dontLoadTabsUntilSelected, 5, 1, 1, 2);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer_6, 8, 0, 1, 1);

        hLayoutDefaultBrowser = new QHBoxLayout();
        hLayoutDefaultBrowser->setObjectName("hLayoutDefaultBrowser");
        checkDefaultBrowser = new QCheckBox(generalPage);
        checkDefaultBrowser->setObjectName("checkDefaultBrowser");
        checkDefaultBrowser->setChecked(false);

        hLayoutDefaultBrowser->addWidget(checkDefaultBrowser);

        checkNowDefaultBrowser = new QPushButton(generalPage);
        checkNowDefaultBrowser->setObjectName("checkNowDefaultBrowser");

        hLayoutDefaultBrowser->addWidget(checkNowDefaultBrowser);

        hSpacerDefaultBrowser = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hLayoutDefaultBrowser->addItem(hSpacerDefaultBrowser);


        gridLayout_6->addLayout(hLayoutDefaultBrowser, 7, 1, 1, 2);

        stackedWidget->addWidget(generalPage);
        appearancePage = new QWidget();
        appearancePage->setObjectName("appearancePage");
        gridLayout_21 = new QGridLayout(appearancePage);
        gridLayout_21->setObjectName("gridLayout_21");
        tabWidget_2 = new QTabWidget(appearancePage);
        tabWidget_2->setObjectName("tabWidget_2");
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        gridLayout_22 = new QGridLayout(tab_5);
        gridLayout_22->setObjectName("gridLayout_22");
        gridLayout_22->setContentsMargins(0, 0, 0, 0);
        themesWidget = new QWidget(tab_5);
        themesWidget->setObjectName("themesWidget");

        gridLayout_22->addWidget(themesWidget, 0, 0, 1, 1);

        tabWidget_2->addTab(tab_5, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout_16 = new QGridLayout(tab_4);
        gridLayout_16->setObjectName("gridLayout_16");
        gridLayout_7 = new QGridLayout();
        gridLayout_7->setObjectName("gridLayout_7");
        showBookmarksToolbar = new QCheckBox(tab_4);
        showBookmarksToolbar->setObjectName("showBookmarksToolbar");

        gridLayout_7->addWidget(showBookmarksToolbar, 1, 0, 1, 1);

        label_56 = new QLabel(tab_4);
        label_56->setObjectName("label_56");

        gridLayout_7->addWidget(label_56, 4, 0, 1, 1);

        showStatusbar = new QCheckBox(tab_4);
        showStatusbar->setObjectName("showStatusbar");

        gridLayout_7->addWidget(showStatusbar, 0, 0, 1, 1);

        showNavigationToolbar = new QCheckBox(tab_4);
        showNavigationToolbar->setObjectName("showNavigationToolbar");

        gridLayout_7->addWidget(showNavigationToolbar, 2, 0, 1, 1);

        instantBookmarksToolbar = new QCheckBox(tab_4);
        instantBookmarksToolbar->setObjectName("instantBookmarksToolbar");

        gridLayout_7->addWidget(instantBookmarksToolbar, 3, 0, 1, 1);

        defaultSideBarWidth = new QSpinBox(tab_4);
        defaultSideBarWidth->setObjectName("defaultSideBarWidth");
        defaultSideBarWidth->setMaximum(9999);

        gridLayout_7->addWidget(defaultSideBarWidth, 4, 1, 1, 1);

        showProfileName = new QCheckBox(tab_4);
        showProfileName->setObjectName("showProfileName");

        gridLayout_7->addWidget(showProfileName, 5, 0, 1, 1);


        gridLayout_16->addLayout(gridLayout_7, 1, 2, 1, 1);

        label_17 = new QLabel(tab_4);
        label_17->setObjectName("label_17");

        gridLayout_16->addWidget(label_17, 3, 0, 1, 3);

        verticalSpacer_12 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_16->addItem(verticalSpacer_12, 6, 2, 1, 1);

        gridLayout_25 = new QGridLayout();
        gridLayout_25->setObjectName("gridLayout_25");
        backgroundColorLoading = new MacToolButton(tab_4);
        backgroundColorLoading->setObjectName("backgroundColorLoading");
        backgroundColorLoading->setStyleSheet(QString::fromUtf8("background: black;"));

        gridLayout_25->addWidget(backgroundColorLoading, 0, 1, 1, 1);

        backgroundColorLoadingReset = new QToolButton(tab_4);
        backgroundColorLoadingReset->setObjectName("backgroundColorLoadingReset");

        gridLayout_25->addWidget(backgroundColorLoadingReset, 0, 2, 1, 1);

        backgroundColorLoaded = new MacToolButton(tab_4);
        backgroundColorLoaded->setObjectName("backgroundColorLoaded");

        gridLayout_25->addWidget(backgroundColorLoaded, 1, 1, 1, 1);

        backgroundColorLoadedReset = new QToolButton(tab_4);
        backgroundColorLoadedReset->setObjectName("backgroundColorLoadedReset");

        gridLayout_25->addWidget(backgroundColorLoadedReset, 1, 2, 1, 1);

        label_49 = new QLabel(tab_4);
        label_49->setObjectName("label_49");

        gridLayout_25->addWidget(label_49, 1, 0, 1, 1);

        label_21 = new QLabel(tab_4);
        label_21->setObjectName("label_21");

        gridLayout_25->addWidget(label_21, 0, 0, 1, 1);

        loadedSwitchDelay = new QSpinBox(tab_4);
        loadedSwitchDelay->setObjectName("loadedSwitchDelay");
        loadedSwitchDelay->setMaximum(5000);
        loadedSwitchDelay->setSingleStep(10);

        gridLayout_25->addWidget(loadedSwitchDelay, 2, 1, 1, 2);

        label_55 = new QLabel(tab_4);
        label_55->setObjectName("label_55");

        gridLayout_25->addWidget(label_55, 2, 0, 1, 1);


        gridLayout_16->addLayout(gridLayout_25, 5, 2, 1, 1);

        label_18 = new QLabel(tab_4);
        label_18->setObjectName("label_18");

        gridLayout_16->addWidget(label_18, 0, 0, 1, 3);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_16->addItem(horizontalSpacer_2, 1, 3, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_16->addItem(horizontalSpacer_8, 1, 0, 1, 1);

        tabWidget_2->addTab(tab_4, QString());

        gridLayout_21->addWidget(tabWidget_2, 0, 0, 1, 1);

        stackedWidget->addWidget(appearancePage);
        tabsPage = new QWidget();
        tabsPage->setObjectName("tabsPage");
        gridLayout_2 = new QGridLayout(tabsPage);
        gridLayout_2->setObjectName("gridLayout_2");
        tabWidget_3 = new QTabWidget(tabsPage);
        tabWidget_3->setObjectName("tabWidget_3");
        tabsBehaviourPage = new QWidget();
        tabsBehaviourPage->setObjectName("tabsBehaviourPage");
        verticalLayout_2 = new QVBoxLayout(tabsBehaviourPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        hideTabsOnTab = new QCheckBox(tabsBehaviourPage);
        hideTabsOnTab->setObjectName("hideTabsOnTab");

        verticalLayout_2->addWidget(hideTabsOnTab);

        activateLastTab = new QCheckBox(tabsBehaviourPage);
        activateLastTab->setObjectName("activateLastTab");

        verticalLayout_2->addWidget(activateLastTab);

        openNewTabAfterActive = new QCheckBox(tabsBehaviourPage);
        openNewTabAfterActive->setObjectName("openNewTabAfterActive");

        verticalLayout_2->addWidget(openNewTabAfterActive);

        openNewEmptyTabAfterActive = new QCheckBox(tabsBehaviourPage);
        openNewEmptyTabAfterActive->setObjectName("openNewEmptyTabAfterActive");

        verticalLayout_2->addWidget(openNewEmptyTabAfterActive);

        openPopupsInTabs = new QCheckBox(tabsBehaviourPage);
        openPopupsInTabs->setObjectName("openPopupsInTabs");

        verticalLayout_2->addWidget(openPopupsInTabs);

        blockAutomaticPopups = new QCheckBox(tabsBehaviourPage);
        blockAutomaticPopups->setObjectName("blockAutomaticPopups");

        verticalLayout_2->addWidget(blockAutomaticPopups);

        alwaysSwitchTabsWithWheel = new QCheckBox(tabsBehaviourPage);
        alwaysSwitchTabsWithWheel->setObjectName("alwaysSwitchTabsWithWheel");

        verticalLayout_2->addWidget(alwaysSwitchTabsWithWheel);

        switchToNewTabs = new QCheckBox(tabsBehaviourPage);
        switchToNewTabs->setObjectName("switchToNewTabs");

        verticalLayout_2->addWidget(switchToNewTabs);

        dontCloseOnLastTab = new QCheckBox(tabsBehaviourPage);
        dontCloseOnLastTab->setObjectName("dontCloseOnLastTab");

        verticalLayout_2->addWidget(dontCloseOnLastTab);

        askWhenClosingMultipleTabs = new QCheckBox(tabsBehaviourPage);
        askWhenClosingMultipleTabs->setObjectName("askWhenClosingMultipleTabs");

        verticalLayout_2->addWidget(askWhenClosingMultipleTabs);

        showClosedTabsButton = new QCheckBox(tabsBehaviourPage);
        showClosedTabsButton->setObjectName("showClosedTabsButton");

        verticalLayout_2->addWidget(showClosedTabsButton);

        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        label_65 = new QLabel(tabsBehaviourPage);
        label_65->setObjectName("label_65");

        horizontalLayout_21->addWidget(label_65);

        showCloseOnInactive = new QComboBox(tabsBehaviourPage);
        showCloseOnInactive->addItem(QString());
        showCloseOnInactive->addItem(QString());
        showCloseOnInactive->addItem(QString());
        showCloseOnInactive->setObjectName("showCloseOnInactive");

        horizontalLayout_21->addWidget(showCloseOnInactive);

        horizontalSpacer_30 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_21->addItem(horizontalSpacer_30);


        verticalLayout_2->addLayout(horizontalLayout_21);

        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_8);

        tabWidget_3->addTab(tabsBehaviourPage, QString());
        addressBarBehaviourPage = new QWidget();
        addressBarBehaviourPage->setObjectName("addressBarBehaviourPage");
        verticalLayout_3 = new QVBoxLayout(addressBarBehaviourPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        label_59 = new QLabel(addressBarBehaviourPage);
        label_59->setObjectName("label_59");

        horizontalLayout_16->addWidget(label_59);

        addressbarCompletion = new QComboBox(addressBarBehaviourPage);
        addressbarCompletion->addItem(QString());
        addressbarCompletion->addItem(QString());
        addressbarCompletion->addItem(QString());
        addressbarCompletion->addItem(QString());
        addressbarCompletion->setObjectName("addressbarCompletion");
        addressbarCompletion->setMinimumSize(QSize(170, 0));

        horizontalLayout_16->addWidget(addressbarCompletion);

        horizontalSpacer_23 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_23);


        verticalLayout_3->addLayout(horizontalLayout_16);

        useInlineCompletion = new QCheckBox(addressBarBehaviourPage);
        useInlineCompletion->setObjectName("useInlineCompletion");

        verticalLayout_3->addWidget(useInlineCompletion);

        completionShowSwitchTab = new QCheckBox(addressBarBehaviourPage);
        completionShowSwitchTab->setObjectName("completionShowSwitchTab");

        verticalLayout_3->addWidget(completionShowSwitchTab);

        alwaysShowGoIcon = new QCheckBox(addressBarBehaviourPage);
        alwaysShowGoIcon->setObjectName("alwaysShowGoIcon");

        verticalLayout_3->addWidget(alwaysShowGoIcon);

        showZoomLabel = new QCheckBox(addressBarBehaviourPage);
        showZoomLabel->setObjectName("showZoomLabel");

        verticalLayout_3->addWidget(showZoomLabel);

        selectAllOnFocus = new QCheckBox(addressBarBehaviourPage);
        selectAllOnFocus->setObjectName("selectAllOnFocus");

        verticalLayout_3->addWidget(selectAllOnFocus);

        selectAllOnClick = new QCheckBox(addressBarBehaviourPage);
        selectAllOnClick->setObjectName("selectAllOnClick");

        verticalLayout_3->addWidget(selectAllOnClick);

        searchFromAddressBar = new QCheckBox(addressBarBehaviourPage);
        searchFromAddressBar->setObjectName("searchFromAddressBar");

        verticalLayout_3->addWidget(searchFromAddressBar);

        searchWithDefaultEngine = new QCheckBox(addressBarBehaviourPage);
        searchWithDefaultEngine->setObjectName("searchWithDefaultEngine");

        verticalLayout_3->addWidget(searchWithDefaultEngine);

        showABSearchSuggestions = new QCheckBox(addressBarBehaviourPage);
        showABSearchSuggestions->setObjectName("showABSearchSuggestions");

        verticalLayout_3->addWidget(showABSearchSuggestions);

        completionPopupExpandToWindow = new QCheckBox(addressBarBehaviourPage);
        completionPopupExpandToWindow->setObjectName("completionPopupExpandToWindow");

        verticalLayout_3->addWidget(completionPopupExpandToWindow);

        verticalSpacer_16 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_16);

        showLoadingInAddressBar = new QCheckBox(addressBarBehaviourPage);
        showLoadingInAddressBar->setObjectName("showLoadingInAddressBar");

        verticalLayout_3->addWidget(showLoadingInAddressBar);

        addressProgressSettings = new QWidget(addressBarBehaviourPage);
        addressProgressSettings->setObjectName("addressProgressSettings");
        horizontalLayout_18 = new QHBoxLayout(addressProgressSettings);
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        horizontalLayout_18->setContentsMargins(-1, 0, -1, 0);
        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer);

        progressStyleSelector = new QComboBox(addressProgressSettings);
        progressStyleSelector->addItem(QString());
        progressStyleSelector->addItem(QString());
        progressStyleSelector->addItem(QString());
        progressStyleSelector->setObjectName("progressStyleSelector");

        horizontalLayout_18->addWidget(progressStyleSelector);

        checkBoxCustomProgressColor = new QCheckBox(addressProgressSettings);
        checkBoxCustomProgressColor->setObjectName("checkBoxCustomProgressColor");

        horizontalLayout_18->addWidget(checkBoxCustomProgressColor);

        progressBarColorSelector = new QWidget(addressProgressSettings);
        progressBarColorSelector->setObjectName("progressBarColorSelector");
        horizontalLayout_19 = new QHBoxLayout(progressBarColorSelector);
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        horizontalLayout_19->setContentsMargins(-1, 0, -1, 0);
        customColorToolButton = new MacToolButton(progressBarColorSelector);
        customColorToolButton->setObjectName("customColorToolButton");

        horizontalLayout_19->addWidget(customColorToolButton);

        resetProgressBarcolor = new MacToolButton(progressBarColorSelector);
        resetProgressBarcolor->setObjectName("resetProgressBarcolor");

        horizontalLayout_19->addWidget(resetProgressBarcolor);


        horizontalLayout_18->addWidget(progressBarColorSelector);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_9);


        verticalLayout_3->addWidget(addressProgressSettings);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_7);

        tabWidget_3->addTab(addressBarBehaviourPage, QString());

        gridLayout_2->addWidget(tabWidget_3, 0, 0, 1, 1);

        stackedWidget->addWidget(tabsPage);
        browsingPage = new QWidget();
        browsingPage->setObjectName("browsingPage");
        gridLayout_9 = new QGridLayout(browsingPage);
        gridLayout_9->setObjectName("gridLayout_9");
        tabWidget = new QTabWidget(browsingPage);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_18 = new QGridLayout(tab);
        gridLayout_18->setObjectName("gridLayout_18");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        allowPlugins = new QCheckBox(tab);
        allowPlugins->setObjectName("allowPlugins");

        verticalLayout->addWidget(allowPlugins);

        intPDFViewer = new QCheckBox(tab);
        intPDFViewer->setObjectName("intPDFViewer");

        verticalLayout->addWidget(intPDFViewer);

        allowJavaScript = new QCheckBox(tab);
        allowJavaScript->setObjectName("allowJavaScript");

        verticalLayout->addWidget(allowJavaScript);

        linksInFocusChain = new QCheckBox(tab);
        linksInFocusChain->setObjectName("linksInFocusChain");

        verticalLayout->addWidget(linksInFocusChain);

        printEBackground = new QCheckBox(tab);
        printEBackground->setObjectName("printEBackground");

        verticalLayout->addWidget(printEBackground);

        animateScrolling = new QCheckBox(tab);
        animateScrolling->setObjectName("animateScrolling");

        verticalLayout->addWidget(animateScrolling);

        spatialNavigation = new QCheckBox(tab);
        spatialNavigation->setObjectName("spatialNavigation");

        verticalLayout->addWidget(spatialNavigation);

        useNativeScrollbars = new QCheckBox(tab);
        useNativeScrollbars->setObjectName("useNativeScrollbars");

        verticalLayout->addWidget(useNativeScrollbars);

        disableVideoAutoPlay = new QCheckBox(tab);
        disableVideoAutoPlay->setObjectName("disableVideoAutoPlay");

        verticalLayout->addWidget(disableVideoAutoPlay);

        webRTCPublicIpOnly = new QCheckBox(tab);
        webRTCPublicIpOnly->setObjectName("webRTCPublicIpOnly");

        verticalLayout->addWidget(webRTCPublicIpOnly);

        dnsPrefetch = new QCheckBox(tab);
        dnsPrefetch->setObjectName("dnsPrefetch");

        verticalLayout->addWidget(dnsPrefetch);

        screenCaptureEnabled = new QCheckBox(tab);
        screenCaptureEnabled->setObjectName("screenCaptureEnabled");

        verticalLayout->addWidget(screenCaptureEnabled);

        hardwareAccel = new QCheckBox(tab);
        hardwareAccel->setObjectName("hardwareAccel");

        verticalLayout->addWidget(hardwareAccel);

        readingFromCanvasEnabled = new QCheckBox(tab);
        readingFromCanvasEnabled->setObjectName("readingFromCanvasEnabled");

        verticalLayout->addWidget(readingFromCanvasEnabled);

        forceDarkMode = new QCheckBox(tab);
        forceDarkMode->setObjectName("forceDarkMode");

        verticalLayout->addWidget(forceDarkMode);

        allowImageAnimation = new QCheckBox(tab);
        allowImageAnimation->setObjectName("allowImageAnimation");

        verticalLayout->addWidget(allowImageAnimation);

        horizontalLayout_22 = new QHBoxLayout();
        horizontalLayout_22->setObjectName("horizontalLayout_22");
        label_16 = new QLabel(tab);
        label_16->setObjectName("label_16");

        horizontalLayout_22->addWidget(label_16);

        prefferColorScheme = new QComboBox(tab);
        prefferColorScheme->setObjectName("prefferColorScheme");

        horizontalLayout_22->addWidget(prefferColorScheme);

        horizontalSpacer_40 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_22->addItem(horizontalSpacer_40);


        verticalLayout->addLayout(horizontalLayout_22);


        gridLayout_18->addLayout(verticalLayout, 0, 0, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_14 = new QLabel(tab);
        label_14->setObjectName("label_14");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_14->sizePolicy().hasHeightForWidth());
        label_14->setSizePolicy(sizePolicy1);

        horizontalLayout_11->addWidget(label_14);

        wheelScroll = new QSpinBox(tab);
        wheelScroll->setObjectName("wheelScroll");
        sizePolicy.setHeightForWidth(wheelScroll->sizePolicy().hasHeightForWidth());
        wheelScroll->setSizePolicy(sizePolicy);
        wheelScroll->setMinimum(1);

        horizontalLayout_11->addWidget(wheelScroll);

        label_26 = new QLabel(tab);
        label_26->setObjectName("label_26");

        horizontalLayout_11->addWidget(label_26);


        gridLayout_18->addLayout(horizontalLayout_11, 2, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        label_44 = new QLabel(tab);
        label_44->setObjectName("label_44");

        horizontalLayout_12->addWidget(label_44);

        defaultZoomLevel = new QComboBox(tab);
        defaultZoomLevel->setObjectName("defaultZoomLevel");

        horizontalLayout_12->addWidget(defaultZoomLevel);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_12);


        gridLayout_18->addLayout(horizontalLayout_12, 3, 0, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_18->addItem(verticalSpacer_9, 4, 0, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_19 = new QGridLayout(tab_2);
        gridLayout_19->setObjectName("gridLayout_19");
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        allowCache = new QCheckBox(tab_2);
        allowCache->setObjectName("allowCache");

        gridLayout_4->addWidget(allowCache, 0, 0, 1, 3);

        horizontalSpacer_33 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_33, 1, 0, 1, 1);

        removeCache = new QCheckBox(tab_2);
        removeCache->setObjectName("removeCache");

        gridLayout_4->addWidget(removeCache, 1, 1, 1, 3);

        maxCacheLabel = new QLabel(tab_2);
        maxCacheLabel->setObjectName("maxCacheLabel");

        gridLayout_4->addWidget(maxCacheLabel, 2, 1, 1, 1);

        cacheMB = new QSpinBox(tab_2);
        cacheMB->setObjectName("cacheMB");
        cacheMB->setMinimum(1);
        cacheMB->setMaximum(999999999);
        cacheMB->setValue(50);

        gridLayout_4->addWidget(cacheMB, 2, 2, 1, 1);

        storeCacheLabel = new QLabel(tab_2);
        storeCacheLabel->setObjectName("storeCacheLabel");
        storeCacheLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(storeCacheLabel, 3, 1, 1, 1);

        horizontalLayout_20 = new QHBoxLayout();
        horizontalLayout_20->setObjectName("horizontalLayout_20");
        cachePath = new QLineEdit(tab_2);
        cachePath->setObjectName("cachePath");

        horizontalLayout_20->addWidget(cachePath);

        changeCachePath = new MacToolButton(tab_2);
        changeCachePath->setObjectName("changeCachePath");

        horizontalLayout_20->addWidget(changeCachePath);


        gridLayout_4->addLayout(horizontalLayout_20, 3, 2, 1, 1);


        gridLayout_19->addLayout(gridLayout_4, 0, 0, 1, 2);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        saveHistory = new QCheckBox(tab_2);
        saveHistory->setObjectName("saveHistory");

        gridLayout_3->addWidget(saveHistory, 0, 0, 1, 3);

        deleteHistoryOnClose = new QCheckBox(tab_2);
        deleteHistoryOnClose->setObjectName("deleteHistoryOnClose");

        gridLayout_3->addWidget(deleteHistoryOnClose, 1, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_4, 1, 0, 1, 1);

        html5storage = new QCheckBox(tab_2);
        html5storage->setObjectName("html5storage");

        gridLayout_3->addWidget(html5storage, 2, 0, 1, 3);

        deleteHtml5storageOnClose = new QCheckBox(tab_2);
        deleteHtml5storageOnClose->setObjectName("deleteHtml5storageOnClose");

        gridLayout_3->addWidget(deleteHtml5storageOnClose, 3, 1, 1, 1);

        horizontalSpacer_21 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_21, 1, 2, 1, 1);

        deleteHtml5storage = new QPushButton(tab_2);
        deleteHtml5storage->setObjectName("deleteHtml5storage");
        sizePolicy.setHeightForWidth(deleteHtml5storage->sizePolicy().hasHeightForWidth());
        deleteHtml5storage->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(deleteHtml5storage, 3, 2, 1, 1);


        gridLayout_19->addLayout(gridLayout_3, 2, 0, 1, 2);

        verticalSpacer_11 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_19->addItem(verticalSpacer_11, 3, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_19->addItem(verticalSpacer, 1, 0, 1, 2);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_8 = new QGridLayout(tab_3);
        gridLayout_8->setObjectName("gridLayout_8");
        verticalSpacer_14 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer_14, 5, 0, 1, 1);

        systemProxy = new QRadioButton(tab_3);
        systemProxy->setObjectName("systemProxy");

        gridLayout_8->addWidget(systemProxy, 1, 0, 1, 2);

        horizontalSpacer_29 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_8->addItem(horizontalSpacer_29, 3, 0, 1, 1);

        manualProxy = new QRadioButton(tab_3);
        manualProxy->setObjectName("manualProxy");

        gridLayout_8->addWidget(manualProxy, 2, 0, 1, 2);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        proxyType = new QComboBox(tab_3);
        proxyType->addItem(QString());
        proxyType->addItem(QString());
        proxyType->setObjectName("proxyType");

        horizontalLayout_9->addWidget(proxyType);

        proxyServer = new QLineEdit(tab_3);
        proxyServer->setObjectName("proxyServer");
        proxyServer->setInputMethodHints(Qt::InputMethodHint::ImhNoAutoUppercase|Qt::InputMethodHint::ImhUrlCharactersOnly);

        horizontalLayout_9->addWidget(proxyServer);

        label_37 = new QLabel(tab_3);
        label_37->setObjectName("label_37");

        horizontalLayout_9->addWidget(label_37);

        proxyPort = new QLineEdit(tab_3);
        proxyPort->setObjectName("proxyPort");
        proxyPort->setMaximumSize(QSize(50, 16777215));

        horizontalLayout_9->addWidget(proxyPort);


        gridLayout_8->addLayout(horizontalLayout_9, 3, 1, 1, 1);

        horizontalLayout_23 = new QHBoxLayout();
        horizontalLayout_23->setObjectName("horizontalLayout_23");
        label_38 = new QLabel(tab_3);
        label_38->setObjectName("label_38");

        horizontalLayout_23->addWidget(label_38);

        proxyUsername = new QLineEdit(tab_3);
        proxyUsername->setObjectName("proxyUsername");

        horizontalLayout_23->addWidget(proxyUsername);

        label_39 = new QLabel(tab_3);
        label_39->setObjectName("label_39");

        horizontalLayout_23->addWidget(label_39);

        proxyPassword = new QLineEdit(tab_3);
        proxyPassword->setObjectName("proxyPassword");
        proxyPassword->setEchoMode(QLineEdit::EchoMode::Password);

        horizontalLayout_23->addWidget(proxyPassword);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_23->addItem(horizontalSpacer_3);


        gridLayout_8->addLayout(horizontalLayout_23, 4, 1, 1, 1);

        noProxy = new QRadioButton(tab_3);
        noProxy->setObjectName("noProxy");

        gridLayout_8->addWidget(noProxy, 0, 0, 1, 2);

        tabWidget->addTab(tab_3, QString());

        gridLayout_9->addWidget(tabWidget, 0, 0, 1, 1);

        stackedWidget->addWidget(browsingPage);
        fontsPage = new QWidget();
        fontsPage->setObjectName("fontsPage");
        gridLayout_15 = new QGridLayout(fontsPage);
        gridLayout_15->setObjectName("gridLayout_15");
        label_27 = new QLabel(fontsPage);
        label_27->setObjectName("label_27");

        gridLayout_15->addWidget(label_27, 0, 0, 2, 3);

        label_6 = new QLabel(fontsPage);
        label_6->setObjectName("label_6");
        sizePolicy1.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy1);

        gridLayout_15->addWidget(label_6, 3, 1, 1, 1);

        label_28 = new QLabel(fontsPage);
        label_28->setObjectName("label_28");

        gridLayout_15->addWidget(label_28, 4, 1, 1, 1);

        fontFixed = new QFontComboBox(fontsPage);
        fontFixed->setObjectName("fontFixed");

        gridLayout_15->addWidget(fontFixed, 4, 2, 1, 1);

        label_29 = new QLabel(fontsPage);
        label_29->setObjectName("label_29");

        gridLayout_15->addWidget(label_29, 5, 1, 1, 1);

        fontSerif = new QFontComboBox(fontsPage);
        fontSerif->setObjectName("fontSerif");

        gridLayout_15->addWidget(fontSerif, 5, 2, 1, 1);

        label_30 = new QLabel(fontsPage);
        label_30->setObjectName("label_30");

        gridLayout_15->addWidget(label_30, 6, 1, 1, 1);

        fontSansSerif = new QFontComboBox(fontsPage);
        fontSansSerif->setObjectName("fontSansSerif");

        gridLayout_15->addWidget(fontSansSerif, 6, 2, 1, 1);

        label_31 = new QLabel(fontsPage);
        label_31->setObjectName("label_31");

        gridLayout_15->addWidget(label_31, 7, 1, 1, 1);

        fontCursive = new QFontComboBox(fontsPage);
        fontCursive->setObjectName("fontCursive");

        gridLayout_15->addWidget(fontCursive, 7, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_15->addItem(verticalSpacer_2, 17, 1, 1, 1);

        horizontalSpacer_11 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_15->addItem(horizontalSpacer_11, 3, 0, 1, 1);

        fontStandard = new QFontComboBox(fontsPage);
        fontStandard->setObjectName("fontStandard");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(fontStandard->sizePolicy().hasHeightForWidth());
        fontStandard->setSizePolicy(sizePolicy2);

        gridLayout_15->addWidget(fontStandard, 3, 2, 1, 1);

        fontFantasy = new QFontComboBox(fontsPage);
        fontFantasy->setObjectName("fontFantasy");

        gridLayout_15->addWidget(fontFantasy, 8, 2, 1, 1);

        label_34 = new QLabel(fontsPage);
        label_34->setObjectName("label_34");

        gridLayout_15->addWidget(label_34, 8, 1, 1, 1);

        label_35 = new QLabel(fontsPage);
        label_35->setObjectName("label_35");

        gridLayout_15->addWidget(label_35, 9, 0, 1, 3);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_33 = new QLabel(fontsPage);
        label_33->setObjectName("label_33");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_33);

        label_32 = new QLabel(fontsPage);
        label_32->setObjectName("label_32");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_32);

        sizeDefault = new QSpinBox(fontsPage);
        sizeDefault->setObjectName("sizeDefault");
        sizePolicy.setHeightForWidth(sizeDefault->sizePolicy().hasHeightForWidth());
        sizeDefault->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, sizeDefault);

        sizeFixed = new QSpinBox(fontsPage);
        sizeFixed->setObjectName("sizeFixed");
        sizePolicy.setHeightForWidth(sizeFixed->sizePolicy().hasHeightForWidth());
        sizeFixed->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, sizeFixed);

        label_46 = new QLabel(fontsPage);
        label_46->setObjectName("label_46");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_46);

        label_47 = new QLabel(fontsPage);
        label_47->setObjectName("label_47");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_47);

        sizeMinimum = new QSpinBox(fontsPage);
        sizeMinimum->setObjectName("sizeMinimum");
        sizePolicy.setHeightForWidth(sizeMinimum->sizePolicy().hasHeightForWidth());
        sizeMinimum->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, sizeMinimum);

        sizeMinimumLogical = new QSpinBox(fontsPage);
        sizeMinimumLogical->setObjectName("sizeMinimumLogical");
        sizePolicy.setHeightForWidth(sizeMinimumLogical->sizePolicy().hasHeightForWidth());
        sizeMinimumLogical->setSizePolicy(sizePolicy);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, sizeMinimumLogical);


        gridLayout_15->addLayout(formLayout, 11, 1, 1, 2);

        stackedWidget->addWidget(fontsPage);
        shortcutsPage = new QWidget();
        shortcutsPage->setObjectName("shortcutsPage");
        gridLayout = new QGridLayout(shortcutsPage);
        gridLayout->setObjectName("gridLayout");
        label_13 = new QLabel(shortcutsPage);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 0, 0, 1, 1);

        switchTabsAlt = new QCheckBox(shortcutsPage);
        switchTabsAlt->setObjectName("switchTabsAlt");

        gridLayout->addWidget(switchTabsAlt, 1, 0, 1, 2);

        loadSpeedDialsCtrl = new QCheckBox(shortcutsPage);
        loadSpeedDialsCtrl->setObjectName("loadSpeedDialsCtrl");

        gridLayout->addWidget(loadSpeedDialsCtrl, 2, 0, 1, 2);

        singleKeyShortcuts = new QCheckBox(shortcutsPage);
        singleKeyShortcuts->setObjectName("singleKeyShortcuts");

        gridLayout->addWidget(singleKeyShortcuts, 3, 0, 1, 2);

        closeAppWithCtrlQ = new QCheckBox(shortcutsPage);
        closeAppWithCtrlQ->setObjectName("closeAppWithCtrlQ");

        gridLayout->addWidget(closeAppWithCtrlQ, 4, 0, 1, 2);

        verticalSpacer_13 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_13, 5, 1, 1, 1);

        stackedWidget->addWidget(shortcutsPage);
        downloadsPage = new QWidget();
        downloadsPage->setObjectName("downloadsPage");
        gridLayout_10 = new QGridLayout(downloadsPage);
        gridLayout_10->setObjectName("gridLayout_10");
        label_23 = new QLabel(downloadsPage);
        label_23->setObjectName("label_23");

        gridLayout_10->addWidget(label_23, 0, 0, 1, 4);

        askEverytime = new QRadioButton(downloadsPage);
        askEverytime->setObjectName("askEverytime");

        gridLayout_10->addWidget(askEverytime, 3, 1, 1, 2);

        useDefined = new QRadioButton(downloadsPage);
        useDefined->setObjectName("useDefined");

        gridLayout_10->addWidget(useDefined, 4, 1, 1, 2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        downLoc = new QLineEdit(downloadsPage);
        downLoc->setObjectName("downLoc");

        horizontalLayout_4->addWidget(downLoc);

        downButt = new MacToolButton(downloadsPage);
        downButt->setObjectName("downButt");

        horizontalLayout_4->addWidget(downButt);


        gridLayout_10->addLayout(horizontalLayout_4, 5, 1, 1, 3);

        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_10->addItem(horizontalSpacer_18, 4, 3, 1, 1);

        horizontalSpacer_19 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_10->addItem(horizontalSpacer_19, 5, 0, 1, 1);

        label_22 = new QLabel(downloadsPage);
        label_22->setObjectName("label_22");

        gridLayout_10->addWidget(label_22, 6, 0, 1, 4);

        closeDownManOnFinish = new QCheckBox(downloadsPage);
        closeDownManOnFinish->setObjectName("closeDownManOnFinish");

        gridLayout_10->addWidget(closeDownManOnFinish, 7, 1, 1, 3);

        label_51 = new QLabel(downloadsPage);
        label_51->setObjectName("label_51");

        gridLayout_10->addWidget(label_51, 10, 0, 1, 4);

        useExternalDownManager = new QCheckBox(downloadsPage);
        useExternalDownManager->setObjectName("useExternalDownManager");

        gridLayout_10->addWidget(useExternalDownManager, 12, 0, 1, 4);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::AllNonFixedFieldsGrow);
        label_52 = new QLabel(downloadsPage);
        label_52->setObjectName("label_52");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_52);

        label_53 = new QLabel(downloadsPage);
        label_53->setObjectName("label_53");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_53);

        externalDownArguments = new QLineEdit(downloadsPage);
        externalDownArguments->setObjectName("externalDownArguments");
        externalDownArguments->setInputMethodHints(Qt::InputMethodHint::ImhNoAutoUppercase);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, externalDownArguments);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        externalDownExecutable = new QLineEdit(downloadsPage);
        externalDownExecutable->setObjectName("externalDownExecutable");

        horizontalLayout_7->addWidget(externalDownExecutable);

        chooseExternalDown = new MacToolButton(downloadsPage);
        chooseExternalDown->setObjectName("chooseExternalDown");

        horizontalLayout_7->addWidget(chooseExternalDown);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_7);

        label_64 = new QLabel(downloadsPage);
        label_64->setObjectName("label_64");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, label_64);


        gridLayout_10->addLayout(formLayout_2, 13, 1, 1, 3);

        verticalSpacer_10 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_10->addItem(verticalSpacer_10, 9, 0, 1, 4);

        stackedWidget->addWidget(downloadsPage);
        passwordManagerPage = new QWidget();
        passwordManagerPage->setObjectName("passwordManagerPage");
        gridLayout_11 = new QGridLayout(passwordManagerPage);
        gridLayout_11->setObjectName("gridLayout_11");
        label_20 = new QLabel(passwordManagerPage);
        label_20->setObjectName("label_20");

        gridLayout_11->addWidget(label_20, 0, 0, 1, 2);

        allowPassManager = new QCheckBox(passwordManagerPage);
        allowPassManager->setObjectName("allowPassManager");

        gridLayout_11->addWidget(allowPassManager, 1, 1, 1, 1);

        horizontalSpacer_14 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_14, 1, 0, 1, 1);

        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_15, 1, 2, 1, 1);

        AutoFillFrame = new QFrame(passwordManagerPage);
        AutoFillFrame->setObjectName("AutoFillFrame");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(AutoFillFrame->sizePolicy().hasHeightForWidth());
        AutoFillFrame->setSizePolicy(sizePolicy3);
        autoFillFrame = new QHBoxLayout(AutoFillFrame);
        autoFillFrame->setObjectName("autoFillFrame");
        autoFillFrame->setSizeConstraint(QLayout::SizeConstraint::SetMinAndMaxSize);

        gridLayout_11->addWidget(AutoFillFrame, 3, 0, 1, 3);

        autoCompletePasswords = new QCheckBox(passwordManagerPage);
        autoCompletePasswords->setObjectName("autoCompletePasswords");

        gridLayout_11->addWidget(autoCompletePasswords, 2, 1, 1, 1);

        stackedWidget->addWidget(passwordManagerPage);
        privacyPage = new QWidget();
        privacyPage->setObjectName("privacyPage");
        gridLayout_12 = new QGridLayout(privacyPage);
        gridLayout_12->setObjectName("gridLayout_12");
        tabWidget_4 = new QTabWidget(privacyPage);
        tabWidget_4->setObjectName("tabWidget_4");
        tab_9 = new QWidget();
        tab_9->setObjectName("tab_9");
        gridLayout_24 = new QGridLayout(tab_9);
        gridLayout_24->setObjectName("gridLayout_24");
        label_19 = new QLabel(tab_9);
        label_19->setObjectName("label_19");

        gridLayout_24->addWidget(label_19, 1, 0, 1, 1);

        cookieManagerBut = new QPushButton(tab_9);
        cookieManagerBut->setObjectName("cookieManagerBut");
        sizePolicy.setHeightForWidth(cookieManagerBut->sizePolicy().hasHeightForWidth());
        cookieManagerBut->setSizePolicy(sizePolicy);

        gridLayout_24->addWidget(cookieManagerBut, 1, 2, 1, 1);

        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_24->addItem(horizontalSpacer_22, 0, 2, 1, 1);

        label_61 = new QLabel(tab_9);
        label_61->setObjectName("label_61");
        label_61->setMouseTracking(true);

        gridLayout_24->addWidget(label_61, 3, 0, 1, 3);

        jsOptionsButton = new QPushButton(tab_9);
        jsOptionsButton->setObjectName("jsOptionsButton");
        sizePolicy.setHeightForWidth(jsOptionsButton->sizePolicy().hasHeightForWidth());
        jsOptionsButton->setSizePolicy(sizePolicy);

        gridLayout_24->addWidget(jsOptionsButton, 5, 2, 1, 1);

        doNotTrack = new QCheckBox(tab_9);
        doNotTrack->setObjectName("doNotTrack");

        gridLayout_24->addWidget(doNotTrack, 8, 2, 1, 1);

        label_12 = new QLabel(tab_9);
        label_12->setObjectName("label_12");

        gridLayout_24->addWidget(label_12, 0, 0, 1, 1);

        horizontalSpacer_20 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_24->addItem(horizontalSpacer_20, 8, 0, 1, 1);

        label_25 = new QLabel(tab_9);
        label_25->setObjectName("label_25");
        label_25->setMouseTracking(false);

        gridLayout_24->addWidget(label_25, 5, 0, 1, 1);

        label_50 = new QLabel(tab_9);
        label_50->setObjectName("label_50");

        gridLayout_24->addWidget(label_50, 7, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_24->addItem(verticalSpacer_3, 9, 0, 1, 3);

        tabWidget_4->addTab(tab_9, QString());
        tab_10 = new QWidget();
        tab_10->setObjectName("tab_10");
        verticalLayout_7 = new QVBoxLayout(tab_10);
        verticalLayout_7->setObjectName("verticalLayout_7");
        siteSettingsHtml5List = new QListWidget(tab_10);
        siteSettingsHtml5List->setObjectName("siteSettingsHtml5List");

        verticalLayout_7->addWidget(siteSettingsHtml5List);

        tabWidget_4->addTab(tab_10, QString());
        tab_11 = new QWidget();
        tab_11->setObjectName("tab_11");
        verticalLayout_6 = new QVBoxLayout(tab_11);
        verticalLayout_6->setObjectName("verticalLayout_6");
        siteSettingsList = new QListWidget(tab_11);
        siteSettingsList->setObjectName("siteSettingsList");

        verticalLayout_6->addWidget(siteSettingsList);

        tabWidget_4->addTab(tab_11, QString());

        gridLayout_12->addWidget(tabWidget_4, 20, 1, 1, 1);

        stackedWidget->addWidget(privacyPage);
        notificationsPage = new QWidget();
        notificationsPage->setObjectName("notificationsPage");
        gridLayout_17 = new QGridLayout(notificationsPage);
        gridLayout_17->setObjectName("gridLayout_17");
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_17->addItem(horizontalSpacer_5, 2, 6, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        label_42 = new QLabel(notificationsPage);
        label_42->setObjectName("label_42");

        horizontalLayout_10->addWidget(label_42);

        notificationTimeout = new QSpinBox(notificationsPage);
        notificationTimeout->setObjectName("notificationTimeout");
        sizePolicy.setHeightForWidth(notificationTimeout->sizePolicy().hasHeightForWidth());
        notificationTimeout->setSizePolicy(sizePolicy);

        horizontalLayout_10->addWidget(notificationTimeout);


        gridLayout_17->addLayout(horizontalLayout_10, 4, 1, 1, 3);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_17->addItem(horizontalSpacer_17, 4, 4, 1, 3);

        label_41 = new QLabel(notificationsPage);
        label_41->setObjectName("label_41");

        gridLayout_17->addWidget(label_41, 0, 0, 1, 4);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_17->addItem(verticalSpacer_4, 8, 1, 1, 1);

        useNativeSystemNotifications = new QRadioButton(notificationsPage);
        useNativeSystemNotifications->setObjectName("useNativeSystemNotifications");
        useNativeSystemNotifications->setEnabled(false);

        gridLayout_17->addWidget(useNativeSystemNotifications, 2, 1, 1, 3);

        doNotUseNotifications = new QRadioButton(notificationsPage);
        doNotUseNotifications->setObjectName("doNotUseNotifications");

        gridLayout_17->addWidget(doNotUseNotifications, 3, 1, 1, 3);

        horizontalSpacer_13 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_17->addItem(horizontalSpacer_13, 1, 0, 1, 1);

        label_43 = new QLabel(notificationsPage);
        label_43->setObjectName("label_43");
        label_43->setWordWrap(true);

        gridLayout_17->addWidget(label_43, 7, 1, 1, 5);

        verticalSpacer_5 = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_17->addItem(verticalSpacer_5, 6, 1, 1, 1);

        useOSDNotifications = new QRadioButton(notificationsPage);
        useOSDNotifications->setObjectName("useOSDNotifications");

        gridLayout_17->addWidget(useOSDNotifications, 1, 1, 1, 3);

        notificationPreview = new QPushButton(notificationsPage);
        notificationPreview->setObjectName("notificationPreview");

        gridLayout_17->addWidget(notificationPreview, 2, 5, 1, 1);

        horizontalSpacer_27 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_17->addItem(horizontalSpacer_27, 2, 4, 1, 1);

        stackedWidget->addWidget(notificationsPage);
        extensionsPage = new QWidget();
        extensionsPage->setObjectName("extensionsPage");
        gridLayout_14 = new QGridLayout(extensionsPage);
        gridLayout_14->setObjectName("gridLayout_14");
        horizontalFrame = new QFrame(extensionsPage);
        horizontalFrame->setObjectName("horizontalFrame");
        sizePolicy3.setHeightForWidth(horizontalFrame->sizePolicy().hasHeightForWidth());
        horizontalFrame->setSizePolicy(sizePolicy3);
        pluginsFrame = new QHBoxLayout(horizontalFrame);
        pluginsFrame->setObjectName("pluginsFrame");
        pluginsFrame->setContentsMargins(0, 0, 0, 0);

        gridLayout_14->addWidget(horizontalFrame, 0, 0, 1, 2);

        stackedWidget->addWidget(extensionsPage);
        spellcheckPage = new QWidget();
        spellcheckPage->setObjectName("spellcheckPage");
        gridLayout_20 = new QGridLayout(spellcheckPage);
        gridLayout_20->setObjectName("gridLayout_20");
        verticalSpacer_18 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_20->addItem(verticalSpacer_18, 4, 4, 1, 1);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_20->addItem(horizontalSpacer_16, 3, 6, 1, 1);

        spellcheckLanguages = new QListWidget(spellcheckPage);
        spellcheckLanguages->setObjectName("spellcheckLanguages");
        spellcheckLanguages->setMaximumSize(QSize(16777215, 1000));
        spellcheckLanguages->setDragEnabled(true);
        spellcheckLanguages->setDragDropMode(QAbstractItemView::DragDropMode::InternalMove);

        gridLayout_20->addWidget(spellcheckLanguages, 3, 2, 1, 1);

        label_40 = new QLabel(spellcheckPage);
        label_40->setObjectName("label_40");
        label_40->setAlignment(Qt::AlignmentFlag::AlignCenter);
        label_40->setOpenExternalLinks(true);

        gridLayout_20->addWidget(label_40, 7, 1, 1, 6);

        spellcheckDirectoriesScrollArea = new QScrollArea(spellcheckPage);
        spellcheckDirectoriesScrollArea->setObjectName("spellcheckDirectoriesScrollArea");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(spellcheckDirectoriesScrollArea->sizePolicy().hasHeightForWidth());
        spellcheckDirectoriesScrollArea->setSizePolicy(sizePolicy4);
        spellcheckDirectoriesScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 775, 83));
        horizontalLayout_14 = new QHBoxLayout(scrollAreaWidgetContents_2);
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        spellcheckDirectories = new QLabel(scrollAreaWidgetContents_2);
        spellcheckDirectories->setObjectName("spellcheckDirectories");

        horizontalLayout_14->addWidget(spellcheckDirectories);

        spellcheckDirectoriesScrollArea->setWidget(scrollAreaWidgetContents_2);

        gridLayout_20->addWidget(spellcheckDirectoriesScrollArea, 6, 1, 1, 6);

        label_48 = new QLabel(spellcheckPage);
        label_48->setObjectName("label_48");

        gridLayout_20->addWidget(label_48, 5, 1, 1, 6);

        spellcheckNoLanguages = new QLabel(spellcheckPage);
        spellcheckNoLanguages->setObjectName("spellcheckNoLanguages");

        gridLayout_20->addWidget(spellcheckNoLanguages, 2, 2, 1, 1);

        label_10 = new QLabel(spellcheckPage);
        label_10->setObjectName("label_10");

        gridLayout_20->addWidget(label_10, 0, 0, 1, 7);

        spellcheckEnabled = new QCheckBox(spellcheckPage);
        spellcheckEnabled->setObjectName("spellcheckEnabled");

        gridLayout_20->addWidget(spellcheckEnabled, 1, 1, 1, 6);

        stackedWidget->addWidget(spellcheckPage);
        otherPage = new QWidget();
        otherPage->setObjectName("otherPage");
        gridLayout_13 = new QGridLayout(otherPage);
        gridLayout_13->setObjectName("gridLayout_13");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_28 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_28);

        protocolHandlers = new QPushButton(otherPage);
        protocolHandlers->setObjectName("protocolHandlers");

        horizontalLayout_5->addWidget(protocolHandlers);

        horizontalSpacer_34 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_34);


        gridLayout_13->addLayout(horizontalLayout_5, 17, 0, 1, 4);

        label_54 = new QLabel(otherPage);
        label_54->setObjectName("label_54");

        gridLayout_13->addWidget(label_54, 20, 0, 1, 1);

        label_11 = new QLabel(otherPage);
        label_11->setObjectName("label_11");
        QFont font;
        font.setBold(true);
        label_11->setFont(font);

        gridLayout_13->addWidget(label_11, 18, 0, 1, 1);

        label_60 = new QLabel(otherPage);
        label_60->setObjectName("label_60");

        gridLayout_13->addWidget(label_60, 7, 0, 1, 6);

        label_66 = new QLabel(otherPage);
        label_66->setObjectName("label_66");

        gridLayout_13->addWidget(label_66, 9, 0, 1, 6);

        label_36 = new QLabel(otherPage);
        label_36->setObjectName("label_36");

        gridLayout_13->addWidget(label_36, 4, 0, 1, 6);

        label_9 = new QLabel(otherPage);
        label_9->setObjectName("label_9");

        gridLayout_13->addWidget(label_9, 23, 0, 1, 6);

        label_7 = new QLabel(otherPage);
        label_7->setObjectName("label_7");

        gridLayout_13->addWidget(label_7, 16, 0, 1, 6);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalSpacer_37 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_37);

        userStyleSheet = new QLineEdit(otherPage);
        userStyleSheet->setObjectName("userStyleSheet");

        horizontalLayout_13->addWidget(userStyleSheet);

        chooseUserStylesheet = new MacToolButton(otherPage);
        chooseUserStylesheet->setObjectName("chooseUserStylesheet");

        horizontalLayout_13->addWidget(chooseUserStylesheet);


        gridLayout_13->addLayout(horizontalLayout_13, 26, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalSpacer_35 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_35);

        certificateManager = new QPushButton(otherPage);
        certificateManager->setObjectName("certificateManager");

        horizontalLayout_6->addWidget(certificateManager);

        horizontalSpacer_36 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_36);


        gridLayout_13->addLayout(horizontalLayout_6, 12, 0, 1, 4);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalSpacer_26 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_26);

        uaManager = new QPushButton(otherPage);
        uaManager->setObjectName("uaManager");

        horizontalLayout_17->addWidget(uaManager);

        horizontalSpacer_25 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_25);


        gridLayout_13->addLayout(horizontalLayout_17, 8, 0, 1, 4);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_13->addItem(horizontalSpacer_6, 5, 5, 1, 1);

        label_15 = new QLabel(otherPage);
        label_15->setObjectName("label_15");

        gridLayout_13->addWidget(label_15, 24, 0, 1, 6);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        horizontalSpacer_38 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_38);

        customSchemes = new QPushButton(otherPage);
        customSchemes->setObjectName("customSchemes");

        horizontalLayout_15->addWidget(customSchemes);

        horizontalSpacer_39 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_39);


        gridLayout_13->addLayout(horizontalLayout_15, 19, 0, 1, 1);

        horizontalLayout_25 = new QHBoxLayout();
        horizontalLayout_25->setObjectName("horizontalLayout_25");
        horizontalSpacer_31 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_25->addItem(horizontalSpacer_31);

        searchEngines = new QPushButton(otherPage);
        searchEngines->setObjectName("searchEngines");

        horizontalLayout_25->addWidget(searchEngines);

        horizontalSpacer_32 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_25->addItem(horizontalSpacer_32);


        gridLayout_13->addLayout(horizontalLayout_25, 10, 0, 1, 4);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalSpacer_24 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_24);

        preferredLanguages = new QPushButton(otherPage);
        preferredLanguages->setObjectName("preferredLanguages");

        horizontalLayout_8->addWidget(preferredLanguages);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_10);


        gridLayout_13->addLayout(horizontalLayout_8, 5, 0, 1, 4);

        verticalSpacer_15 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_13->addItem(verticalSpacer_15, 31, 0, 1, 1);

        label_8 = new QLabel(otherPage);
        label_8->setObjectName("label_8");

        gridLayout_13->addWidget(label_8, 11, 0, 1, 1);

        horizontalLayout_24 = new QHBoxLayout();
        horizontalLayout_24->setObjectName("horizontalLayout_24");
        horizontalSpacer_41 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_24->addItem(horizontalSpacer_41);

        AutoOpenProtocolsButton = new QPushButton(otherPage);
        AutoOpenProtocolsButton->setObjectName("AutoOpenProtocolsButton");

        horizontalLayout_24->addWidget(AutoOpenProtocolsButton);

        horizontalSpacer_42 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_24->addItem(horizontalSpacer_42);


        gridLayout_13->addLayout(horizontalLayout_24, 21, 0, 1, 2);

        stackedWidget->addWidget(otherPage);

        verticalLayout_4->addWidget(stackedWidget);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout_5->addWidget(scrollArea, 2, 1, 1, 2);

        QWidget::setTabOrder(buttonBox, afterLaunch);
        QWidget::setTabOrder(afterLaunch, homepage);
        QWidget::setTabOrder(homepage, useCurrentBut);
        QWidget::setTabOrder(useCurrentBut, newTab);
        QWidget::setTabOrder(newTab, newTabUrl);
        QWidget::setTabOrder(newTabUrl, newTabUseCurrent);
        QWidget::setTabOrder(newTabUseCurrent, checkUpdates);
        QWidget::setTabOrder(checkUpdates, startProfile);
        QWidget::setTabOrder(startProfile, createProfile);
        QWidget::setTabOrder(createProfile, deleteProfile);
        QWidget::setTabOrder(deleteProfile, tabWidget_2);
        QWidget::setTabOrder(tabWidget_2, hideTabsOnTab);
        QWidget::setTabOrder(hideTabsOnTab, askWhenClosingMultipleTabs);
        QWidget::setTabOrder(askWhenClosingMultipleTabs, selectAllOnFocus);
        QWidget::setTabOrder(selectAllOnFocus, selectAllOnClick);
        QWidget::setTabOrder(selectAllOnClick, tabWidget);
        QWidget::setTabOrder(tabWidget, allowPlugins);
        QWidget::setTabOrder(allowPlugins, wheelScroll);
        QWidget::setTabOrder(wheelScroll, fontStandard);
        QWidget::setTabOrder(fontStandard, fontFixed);
        QWidget::setTabOrder(fontFixed, fontSerif);
        QWidget::setTabOrder(fontSerif, fontSansSerif);
        QWidget::setTabOrder(fontSansSerif, fontCursive);
        QWidget::setTabOrder(fontCursive, fontFantasy);
        QWidget::setTabOrder(fontFantasy, askEverytime);
        QWidget::setTabOrder(askEverytime, useDefined);
        QWidget::setTabOrder(useDefined, downLoc);
        QWidget::setTabOrder(downLoc, downButt);
        QWidget::setTabOrder(downButt, closeDownManOnFinish);
        QWidget::setTabOrder(closeDownManOnFinish, allowPassManager);
        QWidget::setTabOrder(allowPassManager, useOSDNotifications);
        QWidget::setTabOrder(useOSDNotifications, useNativeSystemNotifications);
        QWidget::setTabOrder(useNativeSystemNotifications, doNotUseNotifications);
        QWidget::setTabOrder(doNotUseNotifications, notificationTimeout);
        QWidget::setTabOrder(notificationTimeout, preferredLanguages);
        QWidget::setTabOrder(preferredLanguages, userStyleSheet);
        QWidget::setTabOrder(userStyleSheet, chooseUserStylesheet);
        QWidget::setTabOrder(chooseUserStylesheet, allowCache);
        QWidget::setTabOrder(allowCache, cacheMB);
        QWidget::setTabOrder(cacheMB, saveHistory);
        QWidget::setTabOrder(saveHistory, deleteHistoryOnClose);
        QWidget::setTabOrder(deleteHistoryOnClose, proxyServer);
        QWidget::setTabOrder(proxyServer, proxyPort);
        QWidget::setTabOrder(proxyPort, manualProxy);
        QWidget::setTabOrder(manualProxy, systemProxy);
        QWidget::setTabOrder(systemProxy, showStatusbar);
        QWidget::setTabOrder(showStatusbar, showNavigationToolbar);
        QWidget::setTabOrder(showNavigationToolbar, showBookmarksToolbar);

        retranslateUi(Preferences);
        QObject::connect(showLoadingInAddressBar, &QCheckBox::toggled, addressProgressSettings, &QWidget::setEnabled);
        QObject::connect(checkBoxCustomProgressColor, &QCheckBox::toggled, progressBarColorSelector, &QWidget::setEnabled);

        stackedWidget->setCurrentIndex(0);
        tabWidget_2->setCurrentIndex(0);
        tabWidget_3->setCurrentIndex(0);
        tabWidget->setCurrentIndex(0);
        tabWidget_4->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Preferences);
    } // setupUi

    void retranslateUi(QDialog *Preferences)
    {
        Preferences->setWindowTitle(QCoreApplication::translate("Preferences", "Preferences", nullptr));

        const bool __sortingEnabled = listWidget->isSortingEnabled();
        listWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("Preferences", "General", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = listWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("Preferences", "Appearance", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = listWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("Preferences", "Tabs", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = listWidget->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("Preferences", "Browsing", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = listWidget->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("Preferences", "Fonts", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = listWidget->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("Preferences", "Keyboard Shortcuts", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = listWidget->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("Preferences", "Downloads", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = listWidget->item(7);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("Preferences", "Password Manager", nullptr));
        QListWidgetItem *___qlistwidgetitem8 = listWidget->item(8);
        ___qlistwidgetitem8->setText(QCoreApplication::translate("Preferences", "Privacy", nullptr));
        QListWidgetItem *___qlistwidgetitem9 = listWidget->item(9);
        ___qlistwidgetitem9->setText(QCoreApplication::translate("Preferences", "Notifications", nullptr));
        QListWidgetItem *___qlistwidgetitem10 = listWidget->item(10);
        ___qlistwidgetitem10->setText(QCoreApplication::translate("Preferences", "Extensions", nullptr));
        QListWidgetItem *___qlistwidgetitem11 = listWidget->item(11);
        ___qlistwidgetitem11->setText(QCoreApplication::translate("Preferences", "Spell Check", nullptr));
        QListWidgetItem *___qlistwidgetitem12 = listWidget->item(12);
        ___qlistwidgetitem12->setText(QCoreApplication::translate("Preferences", "Other", nullptr));
        listWidget->setSortingEnabled(__sortingEnabled);

        newTabUseCurrent->setText(QCoreApplication::translate("Preferences", "Use current", nullptr));
        cannotDeleteActiveProfileLabel->setText(QCoreApplication::translate("Preferences", "Note: You cannot delete active profile.", nullptr));
        createProfile->setText(QCoreApplication::translate("Preferences", "Create New", nullptr));
        deleteProfile->setText(QCoreApplication::translate("Preferences", "Delete", nullptr));
        label_24->setText(QCoreApplication::translate("Preferences", "<b>Launching</b>", nullptr));
        label_3->setText(QCoreApplication::translate("Preferences", "After launch: ", nullptr));
        afterLaunch->setItemText(0, QCoreApplication::translate("Preferences", "Open blank page", nullptr));
        afterLaunch->setItemText(1, QCoreApplication::translate("Preferences", "Open homepage", nullptr));
        afterLaunch->setItemText(2, QCoreApplication::translate("Preferences", "Open speed dial", nullptr));
        afterLaunch->setItemText(3, QCoreApplication::translate("Preferences", "Restore session", nullptr));
        afterLaunch->setItemText(4, QCoreApplication::translate("Preferences", "Select session", nullptr));

        label->setText(QCoreApplication::translate("Preferences", "Homepage: ", nullptr));
        useCurrentBut->setText(QCoreApplication::translate("Preferences", "Use current", nullptr));
        label_2->setText(QCoreApplication::translate("Preferences", "On new tab: ", nullptr));
        newTab->setItemText(0, QCoreApplication::translate("Preferences", "Open blank tab", nullptr));
        newTab->setItemText(1, QCoreApplication::translate("Preferences", "Open homepage", nullptr));
        newTab->setItemText(2, QCoreApplication::translate("Preferences", "Open speed dial", nullptr));
        newTab->setItemText(3, QCoreApplication::translate("Preferences", "Open other page...", nullptr));

        label_4->setText(QCoreApplication::translate("Preferences", "<b>Profiles</b>", nullptr));
        label_5->setText(QCoreApplication::translate("Preferences", "Startup profile:", nullptr));
        checkUpdates->setText(QCoreApplication::translate("Preferences", "Check for updates on start", nullptr));
        label_45->setText(QCoreApplication::translate("Preferences", "Active profile:", nullptr));
        activeProfile->setText(QString());
        dontLoadTabsUntilSelected->setText(QCoreApplication::translate("Preferences", "Don't load tabs until selected", nullptr));
        checkDefaultBrowser->setText(QCoreApplication::translate("Preferences", "Check to see if Falkon is the default browser on startup", nullptr));
        checkNowDefaultBrowser->setText(QCoreApplication::translate("Preferences", "Check Now", nullptr));
        tabWidget_2->setTabText(tabWidget_2->indexOf(tab_5), QCoreApplication::translate("Preferences", "Themes", nullptr));
        showBookmarksToolbar->setText(QCoreApplication::translate("Preferences", "Show Bookmarks ToolBar on start", nullptr));
        label_56->setText(QCoreApplication::translate("Preferences", "Default minimal sideBar width:", nullptr));
        showStatusbar->setText(QCoreApplication::translate("Preferences", "Show StatusBar on start", nullptr));
        showNavigationToolbar->setText(QCoreApplication::translate("Preferences", "Show Navigation ToolBar on start", nullptr));
        instantBookmarksToolbar->setText(QCoreApplication::translate("Preferences", "Enable instant Bookmarks ToolBar", nullptr));
        defaultSideBarWidth->setSuffix(QCoreApplication::translate("Preferences", "px", nullptr));
        showProfileName->setText(QCoreApplication::translate("Preferences", "Show Profile Name in Window Title", nullptr));
        label_17->setText(QCoreApplication::translate("Preferences", "<html><head/><body><p><span style=\" font-weight:700;\">Web Page Background Colors</span></p></body></html>", nullptr));
        backgroundColorLoading->setText(QCoreApplication::translate("Preferences", "...", nullptr));
        backgroundColorLoadingReset->setText(QCoreApplication::translate("Preferences", "Reset", nullptr));
        backgroundColorLoaded->setText(QCoreApplication::translate("Preferences", "...", nullptr));
        backgroundColorLoadedReset->setText(QCoreApplication::translate("Preferences", "Reset", nullptr));
        label_49->setText(QCoreApplication::translate("Preferences", "Background color when loaded:", nullptr));
        label_21->setText(QCoreApplication::translate("Preferences", "Background color while loading:", nullptr));
        loadedSwitchDelay->setSuffix(QCoreApplication::translate("Preferences", "ms", "miliseconds"));
        label_55->setText(QCoreApplication::translate("Preferences", "Loaded state switch delay:", "Time in milisencods which describes how long to wait after the page was initially loaded before switching the backgroung color to the loaded variant."));
        label_18->setText(QCoreApplication::translate("Preferences", "<b>Browser Window</b>", nullptr));
        tabWidget_2->setTabText(tabWidget_2->indexOf(tab_4), QCoreApplication::translate("Preferences", "Advanced options", nullptr));
        hideTabsOnTab->setText(QCoreApplication::translate("Preferences", "Hide tabs when there is only one tab", nullptr));
        activateLastTab->setText(QCoreApplication::translate("Preferences", "Activate last tab when closing active tab", nullptr));
        openNewTabAfterActive->setText(QCoreApplication::translate("Preferences", "Open new tabs after active tab", nullptr));
        openNewEmptyTabAfterActive->setText(QCoreApplication::translate("Preferences", "Open new empty tabs after active tab", nullptr));
        openPopupsInTabs->setText(QCoreApplication::translate("Preferences", "Open popup windows in tabs", nullptr));
        blockAutomaticPopups->setText(QCoreApplication::translate("Preferences", "Block automatic popups", nullptr));
        alwaysSwitchTabsWithWheel->setText(QCoreApplication::translate("Preferences", "Always switch between tabs with mouse wheel", nullptr));
        switchToNewTabs->setText(QCoreApplication::translate("Preferences", "Automatically switch to newly opened tab", nullptr));
        dontCloseOnLastTab->setText(QCoreApplication::translate("Preferences", "Don't close window upon closing last tab", nullptr));
        askWhenClosingMultipleTabs->setText(QCoreApplication::translate("Preferences", "Ask when closing multiple tabs", nullptr));
        showClosedTabsButton->setText(QCoreApplication::translate("Preferences", "Show closed tabs button", nullptr));
        label_65->setText(QCoreApplication::translate("Preferences", "Show close buttons on inactive tabs:", nullptr));
        showCloseOnInactive->setItemText(0, QCoreApplication::translate("Preferences", "Automatic", nullptr));
        showCloseOnInactive->setItemText(1, QCoreApplication::translate("Preferences", "Always", nullptr));
        showCloseOnInactive->setItemText(2, QCoreApplication::translate("Preferences", "Never", nullptr));

        tabWidget_3->setTabText(tabWidget_3->indexOf(tabsBehaviourPage), QCoreApplication::translate("Preferences", "Tabs behaviour", nullptr));
        label_59->setText(QCoreApplication::translate("Preferences", "Suggest when typing into address bar:", nullptr));
        addressbarCompletion->setItemText(0, QCoreApplication::translate("Preferences", "History and Bookmarks", nullptr));
        addressbarCompletion->setItemText(1, QCoreApplication::translate("Preferences", "History", nullptr));
        addressbarCompletion->setItemText(2, QCoreApplication::translate("Preferences", "Bookmarks", nullptr));
        addressbarCompletion->setItemText(3, QCoreApplication::translate("Preferences", "Nothing", nullptr));

        useInlineCompletion->setText(QCoreApplication::translate("Preferences", "Enable inline suggestions", nullptr));
#if QT_CONFIG(tooltip)
        completionShowSwitchTab->setToolTip(QCoreApplication::translate("Preferences", "Press \"Shift\" to not switch the tab but load the url in the current tab", nullptr));
#endif // QT_CONFIG(tooltip)
        completionShowSwitchTab->setText(QCoreApplication::translate("Preferences", "Propose to switch tab if completed url is already loaded", nullptr));
        alwaysShowGoIcon->setText(QCoreApplication::translate("Preferences", "Always show go icon", nullptr));
        showZoomLabel->setText(QCoreApplication::translate("Preferences", "Show zoom label", nullptr));
        selectAllOnFocus->setText(QCoreApplication::translate("Preferences", "Select all text by double clicking in address bar", nullptr));
        selectAllOnClick->setText(QCoreApplication::translate("Preferences", "Select all text by clicking in address bar", nullptr));
        searchFromAddressBar->setText(QCoreApplication::translate("Preferences", "Enable automatic searching from the address bar", nullptr));
        searchWithDefaultEngine->setText(QCoreApplication::translate("Preferences", "Search with Default Engine", nullptr));
        showABSearchSuggestions->setText(QCoreApplication::translate("Preferences", "Show search suggestions", nullptr));
        completionPopupExpandToWindow->setText(QCoreApplication::translate("Preferences", "Expand suggestion popup to window width", nullptr));
        showLoadingInAddressBar->setText(QCoreApplication::translate("Preferences", "Show loading progress in address bar", nullptr));
        progressStyleSelector->setItemText(0, QCoreApplication::translate("Preferences", "Fill", nullptr));
        progressStyleSelector->setItemText(1, QCoreApplication::translate("Preferences", "Bottom", nullptr));
        progressStyleSelector->setItemText(2, QCoreApplication::translate("Preferences", "Top", nullptr));

        checkBoxCustomProgressColor->setText(QCoreApplication::translate("Preferences", "Custom color:", nullptr));
#if QT_CONFIG(tooltip)
        customColorToolButton->setToolTip(QCoreApplication::translate("Preferences", "Select color", nullptr));
#endif // QT_CONFIG(tooltip)
        customColorToolButton->setText(QCoreApplication::translate("Preferences", "...", nullptr));
        resetProgressBarcolor->setText(QCoreApplication::translate("Preferences", "Reset", nullptr));
        tabWidget_3->setTabText(tabWidget_3->indexOf(addressBarBehaviourPage), QCoreApplication::translate("Preferences", "Address Bar behaviour", nullptr));
        allowPlugins->setText(QCoreApplication::translate("Preferences", "Enable Pepper plugin API (PPAPI)", nullptr));
        intPDFViewer->setText(QCoreApplication::translate("Preferences", "Use built-in PDF viewer (requires PPAPI)", nullptr));
        allowJavaScript->setText(QCoreApplication::translate("Preferences", "Allow JavaScript", nullptr));
        linksInFocusChain->setText(QCoreApplication::translate("Preferences", "Include links in focus chain", nullptr));
        printEBackground->setText(QCoreApplication::translate("Preferences", "Print element background", nullptr));
        animateScrolling->setText(QCoreApplication::translate("Preferences", "Animated scrolling", nullptr));
        spatialNavigation->setText(QCoreApplication::translate("Preferences", "Enable spatial navigation", nullptr));
        useNativeScrollbars->setText(QCoreApplication::translate("Preferences", "Use native scrollbars", nullptr));
        disableVideoAutoPlay->setText(QCoreApplication::translate("Preferences", "Disable automatic playing of videos", nullptr));
        webRTCPublicIpOnly->setText(QCoreApplication::translate("Preferences", "Prevent WebRTC from leaking local IP address", nullptr));
        dnsPrefetch->setText(QCoreApplication::translate("Preferences", "Enable DNS prefetching", nullptr));
        screenCaptureEnabled->setText(QCoreApplication::translate("Preferences", "Enable screen capture", nullptr));
        hardwareAccel->setText(QCoreApplication::translate("Preferences", "Use hardware acceleration (requires restart)", nullptr));
        readingFromCanvasEnabled->setText(QCoreApplication::translate("Preferences", "Allow reading from canvas", nullptr));
        forceDarkMode->setText(QCoreApplication::translate("Preferences", "Force dark mode", nullptr));
        allowImageAnimation->setText(QCoreApplication::translate("Preferences", "Allow image animation", nullptr));
        label_16->setText(QCoreApplication::translate("Preferences", "Preffer color scheme:", nullptr));
        label_14->setText(QCoreApplication::translate("Preferences", "Mouse wheel scrolls", nullptr));
        label_26->setText(QCoreApplication::translate("Preferences", "lines on page", nullptr));
        label_44->setText(QCoreApplication::translate("Preferences", "Default zoom on pages: ", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("Preferences", "Web Configuration", nullptr));
        allowCache->setText(QCoreApplication::translate("Preferences", "Allow storing network cache on disk", nullptr));
        removeCache->setText(QCoreApplication::translate("Preferences", "Delete cache on close", nullptr));
        maxCacheLabel->setText(QCoreApplication::translate("Preferences", "Maximum:", nullptr));
        cacheMB->setSuffix(QCoreApplication::translate("Preferences", " MB", nullptr));
        storeCacheLabel->setText(QCoreApplication::translate("Preferences", "Store cache in:", nullptr));
        changeCachePath->setText(QCoreApplication::translate("Preferences", "...", nullptr));
        saveHistory->setText(QCoreApplication::translate("Preferences", "Allow saving history", nullptr));
        deleteHistoryOnClose->setText(QCoreApplication::translate("Preferences", "Delete history on close", nullptr));
        html5storage->setText(QCoreApplication::translate("Preferences", "Allow local storage of HTML5 web content", nullptr));
        deleteHtml5storageOnClose->setText(QCoreApplication::translate("Preferences", "Delete locally stored HTML5 web content on close", nullptr));
        deleteHtml5storage->setText(QCoreApplication::translate("Preferences", "Delete now", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("Preferences", "Local Storage", nullptr));
        systemProxy->setText(QCoreApplication::translate("Preferences", "System proxy configuration", nullptr));
        manualProxy->setText(QCoreApplication::translate("Preferences", "Manual configuration", nullptr));
        proxyType->setItemText(0, QCoreApplication::translate("Preferences", "HTTP", nullptr));
        proxyType->setItemText(1, QCoreApplication::translate("Preferences", "SOCKS5", nullptr));

        label_37->setText(QCoreApplication::translate("Preferences", "Port:", nullptr));
        label_38->setText(QCoreApplication::translate("Preferences", "Username:", nullptr));
        label_39->setText(QCoreApplication::translate("Preferences", "Password:", nullptr));
        noProxy->setText(QCoreApplication::translate("Preferences", "No proxy", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("Preferences", "Proxy Configuration", nullptr));
        label_27->setText(QCoreApplication::translate("Preferences", "<b>Font Families</b>", nullptr));
        label_6->setText(QCoreApplication::translate("Preferences", "Standard", nullptr));
        label_28->setText(QCoreApplication::translate("Preferences", "Fixed", nullptr));
        label_29->setText(QCoreApplication::translate("Preferences", "Serif", nullptr));
        label_30->setText(QCoreApplication::translate("Preferences", "Sans Serif", nullptr));
        label_31->setText(QCoreApplication::translate("Preferences", "Cursive", nullptr));
        label_34->setText(QCoreApplication::translate("Preferences", "Fantasy", nullptr));
        label_35->setText(QCoreApplication::translate("Preferences", "<b>Font Sizes</b>", nullptr));
        label_33->setText(QCoreApplication::translate("Preferences", "Fixed Font Size", nullptr));
        label_32->setText(QCoreApplication::translate("Preferences", "Default Font Size", nullptr));
        label_46->setText(QCoreApplication::translate("Preferences", "Minimum Font Size", nullptr));
        label_47->setText(QCoreApplication::translate("Preferences", "Minimum Logical Font Size", nullptr));
        label_13->setText(QCoreApplication::translate("Preferences", "<b>Shortcuts</b>", nullptr));
        switchTabsAlt->setText(QCoreApplication::translate("Preferences", "Switch to tabs with Alt + number of tab", nullptr));
        loadSpeedDialsCtrl->setText(QCoreApplication::translate("Preferences", "Load speed dials with Ctrl + number of speed dial", nullptr));
#if QT_CONFIG(tooltip)
        singleKeyShortcuts->setToolTip(QCoreApplication::translate("Preferences", "Existing shortcuts:<br/><b>1</b> - previous tab<br/><b>2</b> - next tab<br/><b>/</b> - search on page", nullptr));
#endif // QT_CONFIG(tooltip)
        singleKeyShortcuts->setText(QCoreApplication::translate("Preferences", "Use single key shortcuts", nullptr));
#if QT_CONFIG(tooltip)
        closeAppWithCtrlQ->setToolTip(QCoreApplication::translate("Preferences", "If unchecked, prevents accidental exit from the application if the Ctrl-W shortcut was intended.", nullptr));
#endif // QT_CONFIG(tooltip)
        closeAppWithCtrlQ->setText(QCoreApplication::translate("Preferences", "Close application with Ctrl-Q", nullptr));
        label_23->setText(QCoreApplication::translate("Preferences", "<b>Download Location</b>", nullptr));
        askEverytime->setText(QCoreApplication::translate("Preferences", "Ask everytime for download location", nullptr));
        useDefined->setText(QCoreApplication::translate("Preferences", "Use defined location: ", nullptr));
        downButt->setText(QCoreApplication::translate("Preferences", "...", nullptr));
        label_22->setText(QCoreApplication::translate("Preferences", "<b>Download Options</b>", nullptr));
        closeDownManOnFinish->setText(QCoreApplication::translate("Preferences", "Close download manager when downloading finishes", nullptr));
        label_51->setText(QCoreApplication::translate("Preferences", "<b>External download manager</b>", nullptr));
        useExternalDownManager->setText(QCoreApplication::translate("Preferences", "Use external download manager", nullptr));
        label_52->setText(QCoreApplication::translate("Preferences", "Executable:", nullptr));
        label_53->setText(QCoreApplication::translate("Preferences", "Arguments:", nullptr));
        externalDownArguments->setPlaceholderText(QCoreApplication::translate("Preferences", "Leave blank if unsure", nullptr));
        chooseExternalDown->setText(QCoreApplication::translate("Preferences", "...", nullptr));
        label_64->setText(QCoreApplication::translate("Preferences", "<b>%d</b> will be replaced with URL to be downloaded", nullptr));
        label_20->setText(QCoreApplication::translate("Preferences", "<b>AutoFill options</b>", nullptr));
        allowPassManager->setText(QCoreApplication::translate("Preferences", "Allow saving passwords from sites", nullptr));
        autoCompletePasswords->setText(QCoreApplication::translate("Preferences", "Automatically complete passwords on sites", nullptr));
        label_19->setText(QCoreApplication::translate("Preferences", "Manage Cookies", nullptr));
        cookieManagerBut->setText(QCoreApplication::translate("Preferences", "Cookies Manager", nullptr));
        label_61->setText(QCoreApplication::translate("Preferences", "<b>JavaScript</b>", nullptr));
        jsOptionsButton->setText(QCoreApplication::translate("Preferences", "JavaScript options", nullptr));
        doNotTrack->setText(QCoreApplication::translate("Preferences", "Send Do Not Track header to servers", nullptr));
        label_12->setText(QCoreApplication::translate("Preferences", "<b>Cookies</b>", nullptr));
        label_25->setText(QCoreApplication::translate("Preferences", "Manage JavaScript privacy options", nullptr));
        label_50->setText(QCoreApplication::translate("Preferences", "<b>Other</b>", nullptr));
        tabWidget_4->setTabText(tabWidget_4->indexOf(tab_9), QCoreApplication::translate("Preferences", "General", nullptr));
        tabWidget_4->setTabText(tabWidget_4->indexOf(tab_10), QCoreApplication::translate("Preferences", "HTML5 Permissions", nullptr));
        tabWidget_4->setTabText(tabWidget_4->indexOf(tab_11), QCoreApplication::translate("Preferences", "Site Settings", nullptr));
        label_42->setText(QCoreApplication::translate("Preferences", "Expiration timeout:", nullptr));
        notificationTimeout->setSuffix(QCoreApplication::translate("Preferences", " seconds", nullptr));
        label_41->setText(QCoreApplication::translate("Preferences", "<b>Notifications</b>", nullptr));
        useNativeSystemNotifications->setText(QCoreApplication::translate("Preferences", "Use Native System Notifications (Linux only)", nullptr));
        doNotUseNotifications->setText(QCoreApplication::translate("Preferences", "Do not use Notifications", nullptr));
        label_43->setText(QCoreApplication::translate("Preferences", "<b>Note: </b>You can change position of OSD Notification by dragging it on the screen.", nullptr));
        useOSDNotifications->setText(QCoreApplication::translate("Preferences", "Use OSD Notifications", nullptr));
        notificationPreview->setText(QCoreApplication::translate("Preferences", "Preview", nullptr));
        label_40->setText(QCoreApplication::translate("Preferences", "For more information about Spell Check, please see <a href=\"https://userbase.kde.org/Falkon#Spell_Check\">wiki</a>.", nullptr));
        label_48->setText(QCoreApplication::translate("Preferences", "<b>Dictionary directories</b>", nullptr));
        spellcheckNoLanguages->setText(QCoreApplication::translate("Preferences", "No languages found", nullptr));
        label_10->setText(QCoreApplication::translate("Preferences", "<b>Spell Check options</b>", nullptr));
        spellcheckEnabled->setText(QCoreApplication::translate("Preferences", "Enable Spell Check", nullptr));
        protocolHandlers->setText(QCoreApplication::translate("Preferences", "Protocol Handlers Manager", nullptr));
        label_54->setText(QCoreApplication::translate("Preferences", "<html><head/><body><p><span style=\" font-weight:700;\">Manage Auto Open protocols</span></p></body></html>", nullptr));
        label_11->setText(QCoreApplication::translate("Preferences", "Manage custom schemes", nullptr));
        label_60->setText(QCoreApplication::translate("Preferences", "<b>Change browser identification</b>", nullptr));
        label_66->setText(QCoreApplication::translate("Preferences", "<b>Manage search engines</b>", nullptr));
        label_36->setText(QCoreApplication::translate("Preferences", "<b>Preferred language for web sites</b>", nullptr));
        label_9->setText(QCoreApplication::translate("Preferences", "<b>User Style Sheet</b>", nullptr));
        label_7->setText(QCoreApplication::translate("Preferences", "<b>Manage protocol handlers</b>", nullptr));
        chooseUserStylesheet->setText(QCoreApplication::translate("Preferences", "...", nullptr));
        certificateManager->setText(QCoreApplication::translate("Preferences", "Certificate Exception Manager", nullptr));
        uaManager->setText(QCoreApplication::translate("Preferences", "User Agent Manager", nullptr));
        label_15->setText(QCoreApplication::translate("Preferences", "Style Sheet automatically loaded with all websites: ", nullptr));
        customSchemes->setText(QCoreApplication::translate("Preferences", "Custom Scheme Manager", nullptr));
        searchEngines->setText(QCoreApplication::translate("Preferences", "Search Engines Manager", nullptr));
        preferredLanguages->setText(QCoreApplication::translate("Preferences", "Languages", nullptr));
        label_8->setText(QCoreApplication::translate("Preferences", "<b>Certificate manager</b>", nullptr));
        AutoOpenProtocolsButton->setText(QCoreApplication::translate("Preferences", "Auto Open protocols", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Preferences: public Ui_Preferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFERENCES_H
