/********************************************************************************
** Form generated from reading UI file 'gm_settings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GM_SETTINGS_H
#define UI_GM_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "clickablelabel.h"
#include "settings/gm_settingslistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_GM_Settings
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *iconLabel;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *enable_gm;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_5;
    GM_SettingsListWidget *listWidget;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_3;
    ClickableLabel *link;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *openDirectory;
    QPushButton *newScript;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *GM_Settings)
    {
        if (GM_Settings->objectName().isEmpty())
            GM_Settings->setObjectName("GM_Settings");
        GM_Settings->resize(513, 416);
        verticalLayout = new QVBoxLayout(GM_Settings);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        iconLabel = new QLabel(GM_Settings);
        iconLabel->setObjectName("iconLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(iconLabel->sizePolicy().hasHeightForWidth());
        iconLabel->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(iconLabel);

        label_2 = new QLabel(GM_Settings);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        enable_gm = new QCheckBox(GM_Settings);
        enable_gm->setObjectName("enable_gm");

        verticalLayout->addWidget(enable_gm);

        label_4 = new QLabel(GM_Settings);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_5 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);

        listWidget = new GM_SettingsListWidget(GM_Settings);
        listWidget->setObjectName("listWidget");
        listWidget->setAlternatingRowColors(true);
        listWidget->setVerticalScrollMode(QAbstractItemView::ScrollMode::ScrollPerPixel);
        listWidget->setUniformItemSizes(true);
        listWidget->setSelectionRectVisible(true);

        horizontalLayout_3->addWidget(listWidget);

        horizontalSpacer_6 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_6);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        label_3 = new QLabel(GM_Settings);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        link = new ClickableLabel(GM_Settings);
        link->setObjectName("link");
        link->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        link->setText(QString::fromUtf8("openuserjs.org"));
        link->setProperty("html-link-look", QVariant(true));

        horizontalLayout_2->addWidget(link);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        openDirectory = new QPushButton(GM_Settings);
        openDirectory->setObjectName("openDirectory");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(openDirectory->sizePolicy().hasHeightForWidth());
        openDirectory->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(openDirectory);

        newScript = new QPushButton(GM_Settings);
        newScript->setObjectName("newScript");

        horizontalLayout_4->addWidget(newScript);

        buttonBox = new QDialogButtonBox(GM_Settings);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Ok);

        horizontalLayout_4->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_4);


        retranslateUi(GM_Settings);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, GM_Settings, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, GM_Settings, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(GM_Settings);
    } // setupUi

    void retranslateUi(QDialog *GM_Settings)
    {
        GM_Settings->setWindowTitle(QCoreApplication::translate("GM_Settings", "GreaseMonkey Scripts", nullptr));
        iconLabel->setText(QString());
        label_2->setText(QCoreApplication::translate("GM_Settings", "<h3>GreaseMonkey Scripts</h3>", nullptr));
        enable_gm->setText(QCoreApplication::translate("GM_Settings", "Enable GreaseMonkey", nullptr));
        label_4->setText(QCoreApplication::translate("GM_Settings", "Double clicking script will show additional information", nullptr));
        label_3->setText(QCoreApplication::translate("GM_Settings", "More scripts can be downloaded from", nullptr));
        openDirectory->setText(QCoreApplication::translate("GM_Settings", "Open scripts directory", nullptr));
        newScript->setText(QCoreApplication::translate("GM_Settings", "New user script", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GM_Settings: public Ui_GM_Settings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GM_SETTINGS_H
