/****************************************************************************
** Meta object code from reading C++ file 'qmlbrowseraction.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.07.80/src/lib/plugins/qml/api/browseraction/qmlbrowseraction.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlbrowseraction.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QmlBrowserActionE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlBrowserAction::qt_create_metaobjectdata<qt_meta_tag_ZN16QmlBrowserActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlBrowserAction",
        "identityChanged",
        "",
        "identity",
        "nameChanged",
        "name",
        "titleChanged",
        "title",
        "toolTipChanged",
        "toolTip",
        "iconChanged",
        "icon",
        "badgeTextChanged",
        "badgeText",
        "popupChanged",
        "QQmlComponent*",
        "popup",
        "locationChanged",
        "Locations",
        "locations",
        "clicked",
        "location",
        "Location",
        "NavigationToolBar",
        "StatusBar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'toolTipChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'badgeTextChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'popupChanged'
        QtMocHelpers::SignalData<void(QQmlComponent *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void(const Locations &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'clicked'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'identity'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'toolTip'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'badgeText'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'popup'
        QtMocHelpers::PropertyData<QQmlComponent*>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'location'
        QtMocHelpers::PropertyData<Locations>(21, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Locations'
        QtMocHelpers::EnumData<Locations>(18, 22, QMC::EnumFlags{}).add({
            {   23, Location::NavigationToolBar },
            {   24, Location::StatusBar },
        }),
    };
    return QtMocHelpers::metaObjectData<QmlBrowserAction, qt_meta_tag_ZN16QmlBrowserActionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlBrowserAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlBrowserActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlBrowserActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QmlBrowserActionE_t>.metaTypes,
    nullptr
} };

void QmlBrowserAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlBrowserAction *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->identityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->toolTipChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->iconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->badgeTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->popupChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 7: _t->locationChanged((*reinterpret_cast<std::add_pointer_t<Locations>>(_a[1]))); break;
        case 8: _t->clicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(const QString & )>(_a, &QmlBrowserAction::identityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(const QString & )>(_a, &QmlBrowserAction::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(const QString & )>(_a, &QmlBrowserAction::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(const QString & )>(_a, &QmlBrowserAction::toolTipChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(const QString & )>(_a, &QmlBrowserAction::iconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(const QString & )>(_a, &QmlBrowserAction::badgeTextChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(QQmlComponent * )>(_a, &QmlBrowserAction::popupChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)(const Locations & )>(_a, &QmlBrowserAction::locationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlBrowserAction::*)()>(_a, &QmlBrowserAction::clicked, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->identity(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->toolTip(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->badgeText(); break;
        case 6: *reinterpret_cast<QQmlComponent**>(_v) = _t->popup(); break;
        case 7: *reinterpret_cast<Locations*>(_v) = _t->location(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIdentity(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setToolTip(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setIcon(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setBadgeText(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setPopup(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 7: _t->setLocation(*reinterpret_cast<Locations*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QmlBrowserAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlBrowserAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlBrowserActionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlBrowserAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QmlBrowserAction::identityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QmlBrowserAction::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QmlBrowserAction::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QmlBrowserAction::toolTipChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QmlBrowserAction::iconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QmlBrowserAction::badgeTextChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QmlBrowserAction::popupChanged(QQmlComponent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QmlBrowserAction::locationChanged(const Locations & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QmlBrowserAction::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
namespace {
struct qt_meta_tag_ZN22QmlBrowserActionButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlBrowserActionButton::qt_create_metaobjectdata<qt_meta_tag_ZN22QmlBrowserActionButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlBrowserActionButton"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlBrowserActionButton, qt_meta_tag_ZN22QmlBrowserActionButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlBrowserActionButton::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractButtonInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QmlBrowserActionButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QmlBrowserActionButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QmlBrowserActionButtonE_t>.metaTypes,
    nullptr
} };

void QmlBrowserActionButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlBrowserActionButton *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QmlBrowserActionButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlBrowserActionButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QmlBrowserActionButtonE_t>.strings))
        return static_cast<void*>(this);
    return AbstractButtonInterface::qt_metacast(_clname);
}

int QmlBrowserActionButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractButtonInterface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
