/********************************************************************************
** Form generated from reading UI file 'historymanager.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HISTORYMANAGER_H
#define UI_HISTORYMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "historytreeview.h"

QT_BEGIN_NAMESPACE

class Ui_HistoryManager
{
public:
    QGridLayout *gridLayout;
    QPushButton *deleteB;
    QPushButton *clearAll;
    QSpacerItem *horizontalSpacer;
    HistoryTreeView *historyTree;

    void setupUi(QWidget *HistoryManager)
    {
        if (HistoryManager->objectName().isEmpty())
            HistoryManager->setObjectName("HistoryManager");
        HistoryManager->resize(735, 547);
        gridLayout = new QGridLayout(HistoryManager);
        gridLayout->setObjectName("gridLayout");
        deleteB = new QPushButton(HistoryManager);
        deleteB->setObjectName("deleteB");

        gridLayout->addWidget(deleteB, 1, 0, 1, 1);

        clearAll = new QPushButton(HistoryManager);
        clearAll->setObjectName("clearAll");

        gridLayout->addWidget(clearAll, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        historyTree = new HistoryTreeView(HistoryManager);
        historyTree->setObjectName("historyTree");
        historyTree->setAlternatingRowColors(true);

        gridLayout->addWidget(historyTree, 0, 0, 1, 4);


        retranslateUi(HistoryManager);

        QMetaObject::connectSlotsByName(HistoryManager);
    } // setupUi

    void retranslateUi(QWidget *HistoryManager)
    {
        HistoryManager->setWindowTitle(QCoreApplication::translate("HistoryManager", "History", nullptr));
        deleteB->setText(QCoreApplication::translate("HistoryManager", "Delete", nullptr));
        clearAll->setText(QCoreApplication::translate("HistoryManager", "Clear All History", nullptr));
    } // retranslateUi

};

namespace Ui {
    class HistoryManager: public Ui_HistoryManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HISTORYMANAGER_H
