/****************************************************************************
** Meta object code from reading C++ file 'tabwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.07.80/src/lib/tabwidget/tabwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8MenuTabsE_t {};
} // unnamed namespace

template <> constexpr inline auto MenuTabs::qt_create_metaobjectdata<qt_meta_tag_ZN8MenuTabsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MenuTabs",
        "closeTab",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'closeTab'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MenuTabs, qt_meta_tag_ZN8MenuTabsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MenuTabs::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8MenuTabsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8MenuTabsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8MenuTabsE_t>.metaTypes,
    nullptr
} };

void MenuTabs::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MenuTabs *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->closeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MenuTabs::*)(int )>(_a, &MenuTabs::closeTab, 0))
            return;
    }
}

const QMetaObject *MenuTabs::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MenuTabs::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8MenuTabsE_t>.strings))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int MenuTabs::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void MenuTabs::closeTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN9TabWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TabWidget::qt_create_metaobjectdata<qt_meta_tag_ZN9TabWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabWidget",
        "changed",
        "",
        "tabInserted",
        "index",
        "tabRemoved",
        "tabMoved",
        "from",
        "to",
        "addView",
        "LoadRequest",
        "req",
        "Qz::NewTabPositionFlags",
        "openFlags",
        "selectLine",
        "pinned",
        "title",
        "position",
        "WebTab*",
        "tab",
        "insertView",
        "addTabFromClipboard",
        "duplicateTab",
        "closeTab",
        "requestCloseTab",
        "reloadTab",
        "reloadAllTabs",
        "stopTab",
        "closeAllButCurrent",
        "closeToRight",
        "closeToLeft",
        "detachTab",
        "loadTab",
        "unloadTab",
        "restoreClosedTab",
        "obj",
        "restoreAllClosedTabs",
        "clearClosedTabsList",
        "moveAddTabButton",
        "posX",
        "tabBarOverFlowChanged",
        "overflowed",
        "loadSettings",
        "aboutToShowTabsMenu",
        "aboutToShowClosedTabsMenu",
        "actionChangeIndex",
        "tabWasMoved",
        "before",
        "after"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabInserted'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'tabRemoved'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'tabMoved'
        QtMocHelpers::SignalData<void(int, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const Qz::NewTabPositionFlags &, bool, bool)>(9, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const Qz::NewTabPositionFlags &, bool)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const Qz::NewTabPositionFlags &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const QString &, const Qz::NewTabPositionFlags &, bool, int, bool)>(9, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 16 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 },
            { QMetaType::Int, 17 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const QString &, const Qz::NewTabPositionFlags &, bool, int)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 16 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 },
            { QMetaType::Int, 17 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const QString &, const Qz::NewTabPositionFlags &, bool)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 16 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const QString &, const Qz::NewTabPositionFlags &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 16 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &, const QString &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(const LoadRequest &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'addView'
        QtMocHelpers::SlotData<int(WebTab *, const Qz::NewTabPositionFlags &)>(9, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'insertView'
        QtMocHelpers::SlotData<int(int, WebTab *, const Qz::NewTabPositionFlags &)>(20, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'addTabFromClipboard'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'duplicateTab'
        QtMocHelpers::SlotData<int(int)>(22, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'requestCloseTab'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'requestCloseTab'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'reloadTab'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'reloadAllTabs'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopTab'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'closeAllButCurrent'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'closeToRight'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'closeToLeft'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'detachTab'
        QtMocHelpers::SlotData<void(int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'loadTab'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'unloadTab'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'restoreClosedTab'
        QtMocHelpers::SlotData<void(QObject *)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 35 },
        }}),
        // Slot 'restoreClosedTab'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'restoreAllClosedTabs'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearClosedTabsList'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveAddTabButton'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'tabBarOverFlowChanged'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToShowTabsMenu'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToShowClosedTabsMenu'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionChangeIndex'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tabWasMoved'
        QtMocHelpers::SlotData<void(int, int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 47 }, { QMetaType::Int, 48 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabWidget, qt_meta_tag_ZN9TabWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<TabStackedWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9TabWidgetE_t>.metaTypes,
    nullptr
} };

void TabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->tabInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->tabRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->tabMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<LoadRequest>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->addView((*reinterpret_cast<std::add_pointer_t<WebTab*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->insertView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<WebTab*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qz::NewTabPositionFlags>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->addTabFromClipboard(); break;
        case 16: { int _r = _t->duplicateTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->closeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->closeTab(); break;
        case 19: _t->requestCloseTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->requestCloseTab(); break;
        case 21: _t->reloadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->reloadAllTabs(); break;
        case 23: _t->stopTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->closeAllButCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->closeToRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->closeToLeft((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->detachTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->loadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->unloadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->restoreClosedTab((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 31: _t->restoreClosedTab(); break;
        case 32: _t->restoreAllClosedTabs(); break;
        case 33: _t->clearClosedTabsList(); break;
        case 34: _t->moveAddTabButton((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->tabBarOverFlowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->loadSettings(); break;
        case 37: _t->aboutToShowTabsMenu(); break;
        case 38: _t->aboutToShowClosedTabsMenu(); break;
        case 39: _t->actionChangeIndex(); break;
        case 40: _t->tabWasMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WebTab* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WebTab* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)()>(_a, &TabWidget::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(int )>(_a, &TabWidget::tabInserted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(int )>(_a, &TabWidget::tabRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabWidget::*)(int , int )>(_a, &TabWidget::tabMoved, 3))
            return;
    }
}

const QMetaObject *TabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TabWidgetE_t>.strings))
        return static_cast<void*>(this);
    return TabStackedWidget::qt_metacast(_clname);
}

int TabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TabStackedWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    return _id;
}

// SIGNAL 0
void TabWidget::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TabWidget::tabInserted(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TabWidget::tabRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TabWidget::tabMoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
