/********************************************************************************
** Form generated from reading UI file 'bookmarksexportdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOOKMARKSEXPORTDIALOG_H
#define UI_BOOKMARKSEXPORTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_BookmarksExportDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QHBoxLayout *horizontalLayout;
    QLineEdit *output;
    QPushButton *chooseOutput;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QLabel *label_2;
    QComboBox *format;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BookmarksExportDialog)
    {
        if (BookmarksExportDialog->objectName().isEmpty())
            BookmarksExportDialog->setObjectName("BookmarksExportDialog");
        BookmarksExportDialog->resize(571, 152);
        verticalLayout_2 = new QVBoxLayout(BookmarksExportDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(BookmarksExportDialog);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        groupBox = new QGroupBox(BookmarksExportDialog);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        output = new QLineEdit(groupBox);
        output->setObjectName("output");
        output->setReadOnly(true);

        horizontalLayout->addWidget(output);

        chooseOutput = new QPushButton(groupBox);
        chooseOutput->setObjectName("chooseOutput");

        horizontalLayout->addWidget(chooseOutput);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");
        label_3->setMinimumSize(QSize(100, 0));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setMinimumSize(QSize(100, 0));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        format = new QComboBox(groupBox);
        format->setObjectName("format");
        format->setMinimumSize(QSize(150, 0));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, format);


        verticalLayout_2->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(BookmarksExportDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(BookmarksExportDialog);

        QMetaObject::connectSlotsByName(BookmarksExportDialog);
    } // setupUi

    void retranslateUi(QDialog *BookmarksExportDialog)
    {
        BookmarksExportDialog->setWindowTitle(QCoreApplication::translate("BookmarksExportDialog", "Export Bookmarks", nullptr));
        label->setText(QCoreApplication::translate("BookmarksExportDialog", "<b>Export Bookmarks</b>", nullptr));
        groupBox->setTitle(QCoreApplication::translate("BookmarksExportDialog", "Export options", nullptr));
        chooseOutput->setText(QCoreApplication::translate("BookmarksExportDialog", "Choose...", nullptr));
        label_3->setText(QCoreApplication::translate("BookmarksExportDialog", "Output File:", nullptr));
        label_2->setText(QCoreApplication::translate("BookmarksExportDialog", "Format:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BookmarksExportDialog: public Ui_BookmarksExportDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BOOKMARKSEXPORTDIALOG_H
