/****************************************************************************
** Meta object code from reading C++ file 'bookmarks.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.07.80/src/lib/bookmarks/bookmarks.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bookmarks.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9BookmarksE_t {};
} // unnamed namespace

template <> constexpr inline auto Bookmarks::qt_create_metaobjectdata<qt_meta_tag_ZN9BookmarksE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bookmarks",
        "bookmarkAdded",
        "",
        "BookmarkItem*",
        "item",
        "bookmarkRemoved",
        "bookmarkChanged",
        "showOnlyIconsInToolbarChanged",
        "show",
        "showOnlyTextInToolbarChanged",
        "setShowOnlyIconsInToolbar",
        "state",
        "setShowOnlyTextInToolbar",
        "saveSettings"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bookmarkAdded'
        QtMocHelpers::SignalData<void(BookmarkItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'bookmarkRemoved'
        QtMocHelpers::SignalData<void(BookmarkItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'bookmarkChanged'
        QtMocHelpers::SignalData<void(BookmarkItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'showOnlyIconsInToolbarChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'showOnlyTextInToolbarChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'setShowOnlyIconsInToolbar'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setShowOnlyTextInToolbar'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'saveSettings'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Bookmarks, qt_meta_tag_ZN9BookmarksE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Bookmarks::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BookmarksE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BookmarksE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9BookmarksE_t>.metaTypes,
    nullptr
} };

void Bookmarks::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Bookmarks *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bookmarkAdded((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 1: _t->bookmarkRemoved((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 2: _t->bookmarkChanged((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 3: _t->showOnlyIconsInToolbarChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->showOnlyTextInToolbarChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setShowOnlyIconsInToolbar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setShowOnlyTextInToolbar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->saveSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Bookmarks::*)(BookmarkItem * )>(_a, &Bookmarks::bookmarkAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bookmarks::*)(BookmarkItem * )>(_a, &Bookmarks::bookmarkRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bookmarks::*)(BookmarkItem * )>(_a, &Bookmarks::bookmarkChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bookmarks::*)(bool )>(_a, &Bookmarks::showOnlyIconsInToolbarChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bookmarks::*)(bool )>(_a, &Bookmarks::showOnlyTextInToolbarChanged, 4))
            return;
    }
}

const QMetaObject *Bookmarks::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bookmarks::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BookmarksE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Bookmarks::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Bookmarks::bookmarkAdded(BookmarkItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Bookmarks::bookmarkRemoved(BookmarkItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Bookmarks::bookmarkChanged(BookmarkItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Bookmarks::showOnlyIconsInToolbarChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Bookmarks::showOnlyTextInToolbarChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
