/********************************************************************************
** Form generated from reading UI file 'gm_settingsscriptinfo.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GM_SETTINGSSCRIPTINFO_H
#define UI_GM_SETTINGSSCRIPTINFO_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include "squeezelabelv2.h"

QT_BEGIN_NAMESPACE

class Ui_GM_SettingsScriptInfo
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_8;
    QTextBrowser *description;
    QTextBrowser *exclude;
    SqueezeLabelV2 *name;
    QLabel *label_4;
    QLabel *labelVersion;
    QLabel *label_7;
    QLabel *version;
    QLabel *label_3;
    QLabel *startAt;
    SqueezeLabelV2 *url;
    QLabel *labelUrl;
    QTextBrowser *include;
    QLabel *label_9;
    QLabel *label;
    QLabel *nspace;
    QHBoxLayout *horizontalLayout;
    QPushButton *editInEditor;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *GM_SettingsScriptInfo)
    {
        if (GM_SettingsScriptInfo->objectName().isEmpty())
            GM_SettingsScriptInfo->setObjectName("GM_SettingsScriptInfo");
        GM_SettingsScriptInfo->resize(485, 408);
        verticalLayout = new QVBoxLayout(GM_SettingsScriptInfo);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_8 = new QLabel(GM_SettingsScriptInfo);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_8, 6, 0, 1, 1);

        description = new QTextBrowser(GM_SettingsScriptInfo);
        description->setObjectName("description");

        gridLayout->addWidget(description, 5, 1, 1, 1);

        exclude = new QTextBrowser(GM_SettingsScriptInfo);
        exclude->setObjectName("exclude");

        gridLayout->addWidget(exclude, 7, 1, 1, 1);

        name = new SqueezeLabelV2(GM_SettingsScriptInfo);
        name->setObjectName("name");
        name->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(name, 0, 1, 1, 1);

        label_4 = new QLabel(GM_SettingsScriptInfo);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 5, 0, 1, 1);

        labelVersion = new QLabel(GM_SettingsScriptInfo);
        labelVersion->setObjectName("labelVersion");
        labelVersion->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(labelVersion, 2, 0, 1, 1);

        label_7 = new QLabel(GM_SettingsScriptInfo);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_7, 4, 0, 1, 1);

        version = new QLabel(GM_SettingsScriptInfo);
        version->setObjectName("version");
        version->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(version, 2, 1, 1, 1);

        label_3 = new QLabel(GM_SettingsScriptInfo);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        startAt = new QLabel(GM_SettingsScriptInfo);
        startAt->setObjectName("startAt");
        startAt->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(startAt, 4, 1, 1, 1);

        url = new SqueezeLabelV2(GM_SettingsScriptInfo);
        url->setObjectName("url");
        url->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(url, 3, 1, 1, 1);

        labelUrl = new QLabel(GM_SettingsScriptInfo);
        labelUrl->setObjectName("labelUrl");
        labelUrl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(labelUrl, 3, 0, 1, 1);

        include = new QTextBrowser(GM_SettingsScriptInfo);
        include->setObjectName("include");

        gridLayout->addWidget(include, 6, 1, 1, 1);

        label_9 = new QLabel(GM_SettingsScriptInfo);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_9, 7, 0, 1, 1);

        label = new QLabel(GM_SettingsScriptInfo);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        nspace = new QLabel(GM_SettingsScriptInfo);
        nspace->setObjectName("nspace");

        gridLayout->addWidget(nspace, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        editInEditor = new QPushButton(GM_SettingsScriptInfo);
        editInEditor->setObjectName("editInEditor");

        horizontalLayout->addWidget(editInEditor);

        buttonBox = new QDialogButtonBox(GM_SettingsScriptInfo);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(GM_SettingsScriptInfo);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, GM_SettingsScriptInfo, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, GM_SettingsScriptInfo, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(GM_SettingsScriptInfo);
    } // setupUi

    void retranslateUi(QDialog *GM_SettingsScriptInfo)
    {
        label_8->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Runs at:", nullptr));
        name->setText(QString());
        label_4->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Description:", nullptr));
        labelVersion->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Version:", nullptr));
        label_7->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Start at:", nullptr));
        version->setText(QString());
        label_3->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Name:", nullptr));
        startAt->setText(QString());
        url->setText(QString());
        labelUrl->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "URL:", nullptr));
        label_9->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Does not run at:", nullptr));
        label->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Namespace:", nullptr));
        editInEditor->setText(QCoreApplication::translate("GM_SettingsScriptInfo", "Edit in text editor", nullptr));
        (void)GM_SettingsScriptInfo;
    } // retranslateUi

};

namespace Ui {
    class GM_SettingsScriptInfo: public Ui_GM_SettingsScriptInfo {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GM_SETTINGSSCRIPTINFO_H
