/****************************************************************************
** Meta object code from reading C++ file 'bookmarksmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.07.80/src/lib/bookmarks/bookmarksmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bookmarksmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13BookmarksMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto BookmarksMenu::qt_create_metaobjectdata<qt_meta_tag_ZN13BookmarksMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BookmarksMenu",
        "bookmarkPage",
        "",
        "bookmarkAllTabs",
        "showBookmarksManager",
        "bookmarksChanged",
        "aboutToShow",
        "menuAboutToShow",
        "menuAboutToHide",
        "menuMiddleClicked",
        "Menu*",
        "menu",
        "bookmarkActivated",
        "bookmarkCtrlActivated",
        "bookmarkShiftActivated",
        "openFolder",
        "BookmarkItem*",
        "item",
        "openBookmark",
        "openBookmarkInNewTab",
        "openBookmarkInNewWindow"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'bookmarkPage'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bookmarkAllTabs'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showBookmarksManager'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bookmarksChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToShow'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'menuAboutToShow'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'menuAboutToHide'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'menuMiddleClicked'
        QtMocHelpers::SlotData<void(Menu *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'bookmarkActivated'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bookmarkCtrlActivated'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bookmarkShiftActivated'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openFolder'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'openBookmark'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'openBookmarkInNewTab'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'openBookmarkInNewWindow'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BookmarksMenu, qt_meta_tag_ZN13BookmarksMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BookmarksMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<Menu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookmarksMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookmarksMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13BookmarksMenuE_t>.metaTypes,
    nullptr
} };

void BookmarksMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BookmarksMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bookmarkPage(); break;
        case 1: _t->bookmarkAllTabs(); break;
        case 2: _t->showBookmarksManager(); break;
        case 3: _t->bookmarksChanged(); break;
        case 4: _t->aboutToShow(); break;
        case 5: _t->menuAboutToShow(); break;
        case 6: _t->menuAboutToHide(); break;
        case 7: _t->menuMiddleClicked((*reinterpret_cast<std::add_pointer_t<Menu*>>(_a[1]))); break;
        case 8: _t->bookmarkActivated(); break;
        case 9: _t->bookmarkCtrlActivated(); break;
        case 10: _t->bookmarkShiftActivated(); break;
        case 11: _t->openFolder((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 12: _t->openBookmark((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 13: _t->openBookmarkInNewTab((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 14: _t->openBookmarkInNewWindow((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Menu* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *BookmarksMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BookmarksMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookmarksMenuE_t>.strings))
        return static_cast<void*>(this);
    return Menu::qt_metacast(_clname);
}

int BookmarksMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Menu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
