/****************************************************************************
** Meta object code from reading C++ file 'qmlplugininterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.07.80/src/lib/plugins/qml/qmlplugininterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlplugininterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18QmlPluginInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlPluginInterface::qt_create_metaobjectdata<qt_meta_tag_ZN18QmlPluginInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlPluginInterface",
        "DefaultProperty",
        "childItems",
        "qmlPluginUnloaded",
        "",
        "init",
        "QJSValue",
        "unload",
        "testPlugin",
        "populateWebViewMenu",
        "settingsWindow",
        "QQmlComponent*",
        "mouseDoubleClick",
        "mousePress",
        "mouseRelease",
        "mouseMove",
        "wheelEvent",
        "keyPress",
        "keyRelease",
        "acceptNavigationRequest",
        "newWindowRequested",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'qmlPluginUnloaded'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'init'
        QtMocHelpers::PropertyData<QJSValue>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'unload'
        QtMocHelpers::PropertyData<QJSValue>(7, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'testPlugin'
        QtMocHelpers::PropertyData<QJSValue>(8, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'populateWebViewMenu'
        QtMocHelpers::PropertyData<QJSValue>(9, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'settingsWindow'
        QtMocHelpers::PropertyData<QQmlComponent*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'mouseDoubleClick'
        QtMocHelpers::PropertyData<QJSValue>(12, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'mousePress'
        QtMocHelpers::PropertyData<QJSValue>(13, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'mouseRelease'
        QtMocHelpers::PropertyData<QJSValue>(14, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'mouseMove'
        QtMocHelpers::PropertyData<QJSValue>(15, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'wheelEvent'
        QtMocHelpers::PropertyData<QJSValue>(16, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'keyPress'
        QtMocHelpers::PropertyData<QJSValue>(17, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'keyRelease'
        QtMocHelpers::PropertyData<QJSValue>(18, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'acceptNavigationRequest'
        QtMocHelpers::PropertyData<QJSValue>(19, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'newWindowRequested'
        QtMocHelpers::PropertyData<QJSValue>(20, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'childItems'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QmlPluginInterface, qt_meta_tag_ZN18QmlPluginInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QmlPluginInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QmlPluginInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QmlPluginInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18QmlPluginInterfaceE_t>.metaTypes,
    nullptr
} };

void QmlPluginInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlPluginInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->qmlPluginUnloaded(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlPluginInterface::*)()>(_a, &QmlPluginInterface::qmlPluginUnloaded, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
        case 12:
        case 11:
        case 10:
        case 9:
        case 8:
        case 7:
        case 6:
        case 5:
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QJSValue*>(_v) = _t->readInit(); break;
        case 1: *reinterpret_cast<QJSValue*>(_v) = _t->readUnload(); break;
        case 2: *reinterpret_cast<QJSValue*>(_v) = _t->readTestPlugin(); break;
        case 3: *reinterpret_cast<QJSValue*>(_v) = _t->readPopulateWebViewMenu(); break;
        case 4: *reinterpret_cast<QQmlComponent**>(_v) = _t->settingsWindow(); break;
        case 5: *reinterpret_cast<QJSValue*>(_v) = _t->readMouseDoubleClick(); break;
        case 6: *reinterpret_cast<QJSValue*>(_v) = _t->readMousePress(); break;
        case 7: *reinterpret_cast<QJSValue*>(_v) = _t->readMouseRelease(); break;
        case 8: *reinterpret_cast<QJSValue*>(_v) = _t->readMouseMove(); break;
        case 9: *reinterpret_cast<QJSValue*>(_v) = _t->readWheelEvent(); break;
        case 10: *reinterpret_cast<QJSValue*>(_v) = _t->readKeyPress(); break;
        case 11: *reinterpret_cast<QJSValue*>(_v) = _t->readKeyRelease(); break;
        case 12: *reinterpret_cast<QJSValue*>(_v) = _t->readAcceptNavigationRequest(); break;
        case 13: *reinterpret_cast<QJSValue*>(_v) = _t->readNewWindowRequested(); break;
        case 14: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->childItems(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInit(*reinterpret_cast<QJSValue*>(_v)); break;
        case 1: _t->setUnload(*reinterpret_cast<QJSValue*>(_v)); break;
        case 2: _t->setTestPlugin(*reinterpret_cast<QJSValue*>(_v)); break;
        case 3: _t->setPopulateWebViewMenu(*reinterpret_cast<QJSValue*>(_v)); break;
        case 4: _t->setSettingsWindow(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 5: _t->setMouseDoubleClick(*reinterpret_cast<QJSValue*>(_v)); break;
        case 6: _t->setMousePress(*reinterpret_cast<QJSValue*>(_v)); break;
        case 7: _t->setMouseRelease(*reinterpret_cast<QJSValue*>(_v)); break;
        case 8: _t->setMouseMove(*reinterpret_cast<QJSValue*>(_v)); break;
        case 9: _t->setWheelEvent(*reinterpret_cast<QJSValue*>(_v)); break;
        case 10: _t->setKeyPress(*reinterpret_cast<QJSValue*>(_v)); break;
        case 11: _t->setKeyRelease(*reinterpret_cast<QJSValue*>(_v)); break;
        case 12: _t->setAcceptNavigationRequest(*reinterpret_cast<QJSValue*>(_v)); break;
        case 13: _t->setNewWindowRequested(*reinterpret_cast<QJSValue*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QmlPluginInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlPluginInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QmlPluginInterfaceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PluginInterface"))
        return static_cast< PluginInterface*>(this);
    if (!strcmp(_clname, "Falkon.Browser.PluginInterface/2.5"))
        return static_cast< PluginInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlPluginInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void QmlPluginInterface::qmlPluginUnloaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
