/********************************************************************************
** Form generated from reading UI file 'siteinfopermissionitem.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SITEINFOPERMISSIONITEM_H
#define UI_SITEINFOPERMISSIONITEM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SiteInfoPermissionItem
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QRadioButton *radioDefault;
    QLabel *labelDefaultPermission;
    QSpacerItem *horizontalSpacer;
    QRadioButton *radioAsk;
    QRadioButton *radioAllow;
    QRadioButton *radioDeny;

    void setupUi(QWidget *SiteInfoPermissionItem)
    {
        if (SiteInfoPermissionItem->objectName().isEmpty())
            SiteInfoPermissionItem->setObjectName("SiteInfoPermissionItem");
        SiteInfoPermissionItem->resize(556, 66);
        verticalLayout = new QVBoxLayout(SiteInfoPermissionItem);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(SiteInfoPermissionItem);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);

        verticalLayout->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        radioDefault = new QRadioButton(SiteInfoPermissionItem);
        radioDefault->setObjectName("radioDefault");

        horizontalLayout->addWidget(radioDefault);

        labelDefaultPermission = new QLabel(SiteInfoPermissionItem);
        labelDefaultPermission->setObjectName("labelDefaultPermission");
        labelDefaultPermission->setEnabled(false);

        horizontalLayout->addWidget(labelDefaultPermission);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        radioAsk = new QRadioButton(SiteInfoPermissionItem);
        radioAsk->setObjectName("radioAsk");

        horizontalLayout->addWidget(radioAsk);

        radioAllow = new QRadioButton(SiteInfoPermissionItem);
        radioAllow->setObjectName("radioAllow");

        horizontalLayout->addWidget(radioAllow);

        radioDeny = new QRadioButton(SiteInfoPermissionItem);
        radioDeny->setObjectName("radioDeny");

        horizontalLayout->addWidget(radioDeny);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(SiteInfoPermissionItem);

        QMetaObject::connectSlotsByName(SiteInfoPermissionItem);
    } // setupUi

    void retranslateUi(QWidget *SiteInfoPermissionItem)
    {
        label->setText(QString());
        radioDefault->setText(QCoreApplication::translate("SiteInfoPermissionItem", "Default", nullptr));
        labelDefaultPermission->setText(QString());
        radioAsk->setText(QCoreApplication::translate("SiteInfoPermissionItem", "Ask", nullptr));
        radioAllow->setText(QCoreApplication::translate("SiteInfoPermissionItem", "Allow", nullptr));
        radioDeny->setText(QCoreApplication::translate("SiteInfoPermissionItem", "Deny", nullptr));
        (void)SiteInfoPermissionItem;
    } // retranslateUi

};

namespace Ui {
    class SiteInfoPermissionItem: public Ui_SiteInfoPermissionItem {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SITEINFOPERMISSIONITEM_H
