/********************************************************************************
** Form generated from reading UI file 'masterpassworddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MASTERPASSWORDDIALOG_H
#define UI_MASTERPASSWORDDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCommandLinkButton>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MasterPasswordDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QStackedWidget *stackedWidget;
    QWidget *pageSettings;
    QVBoxLayout *verticalLayout_3;
    QCommandLinkButton *setMasterPassword;
    QCommandLinkButton *clearMasterPassword;
    QDialogButtonBox *buttonBox;
    QWidget *pageSetMasterPassword;
    QVBoxLayout *verticalLayout;
    QLabel *label_4;
    QFormLayout *formLayout;
    QLabel *labelCurrentPassword;
    QLabel *label_2;
    QLabel *label_3;
    QLineEdit *currentPassword;
    QLineEdit *newPassword;
    QLineEdit *confirmPassword;
    QLabel *label_5;
    QDialogButtonBox *buttonBoxMasterPassword;

    void setupUi(QDialog *MasterPasswordDialog)
    {
        if (MasterPasswordDialog->objectName().isEmpty())
            MasterPasswordDialog->setObjectName("MasterPasswordDialog");
        MasterPasswordDialog->resize(436, 230);
        MasterPasswordDialog->setMinimumSize(QSize(430, 230));
        verticalLayout_2 = new QVBoxLayout(MasterPasswordDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        stackedWidget = new QStackedWidget(MasterPasswordDialog);
        stackedWidget->setObjectName("stackedWidget");
        pageSettings = new QWidget();
        pageSettings->setObjectName("pageSettings");
        verticalLayout_3 = new QVBoxLayout(pageSettings);
        verticalLayout_3->setObjectName("verticalLayout_3");
        setMasterPassword = new QCommandLinkButton(pageSettings);
        setMasterPassword->setObjectName("setMasterPassword");

        verticalLayout_3->addWidget(setMasterPassword);

        clearMasterPassword = new QCommandLinkButton(pageSettings);
        clearMasterPassword->setObjectName("clearMasterPassword");

        verticalLayout_3->addWidget(clearMasterPassword);

        buttonBox = new QDialogButtonBox(pageSettings);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout_3->addWidget(buttonBox);

        stackedWidget->addWidget(pageSettings);
        pageSetMasterPassword = new QWidget();
        pageSetMasterPassword->setObjectName("pageSetMasterPassword");
        verticalLayout = new QVBoxLayout(pageSetMasterPassword);
        verticalLayout->setObjectName("verticalLayout");
        label_4 = new QLabel(pageSetMasterPassword);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        verticalLayout->addWidget(label_4);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        labelCurrentPassword = new QLabel(pageSetMasterPassword);
        labelCurrentPassword->setObjectName("labelCurrentPassword");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelCurrentPassword);

        label_2 = new QLabel(pageSetMasterPassword);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        label_3 = new QLabel(pageSetMasterPassword);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        currentPassword = new QLineEdit(pageSetMasterPassword);
        currentPassword->setObjectName("currentPassword");
        currentPassword->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, currentPassword);

        newPassword = new QLineEdit(pageSetMasterPassword);
        newPassword->setObjectName("newPassword");
        newPassword->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, newPassword);

        confirmPassword = new QLineEdit(pageSetMasterPassword);
        confirmPassword->setObjectName("confirmPassword");
        confirmPassword->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, confirmPassword);


        verticalLayout->addLayout(formLayout);

        label_5 = new QLabel(pageSetMasterPassword);
        label_5->setObjectName("label_5");
        label_5->setWordWrap(true);

        verticalLayout->addWidget(label_5);

        buttonBoxMasterPassword = new QDialogButtonBox(pageSetMasterPassword);
        buttonBoxMasterPassword->setObjectName("buttonBoxMasterPassword");
        buttonBoxMasterPassword->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBoxMasterPassword);

        stackedWidget->addWidget(pageSetMasterPassword);

        verticalLayout_2->addWidget(stackedWidget);


        retranslateUi(MasterPasswordDialog);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MasterPasswordDialog);
    } // setupUi

    void retranslateUi(QDialog *MasterPasswordDialog)
    {
        MasterPasswordDialog->setWindowTitle(QCoreApplication::translate("MasterPasswordDialog", "Encrypted DataBase Settings", nullptr));
        setMasterPassword->setText(QCoreApplication::translate("MasterPasswordDialog", "Set/Change Master Password...", nullptr));
        setMasterPassword->setDescription(QCoreApplication::translate("MasterPasswordDialog", "This backend does not work without a master password.", nullptr));
        clearMasterPassword->setText(QCoreApplication::translate("MasterPasswordDialog", "Clear Master Password...", nullptr));
        clearMasterPassword->setDescription(QCoreApplication::translate("MasterPasswordDialog", "This option clears the master password and moves all encrypted data to the \"DataBase (Plain Text)\" backend, and switches to it.", nullptr));
        label_4->setText(QCoreApplication::translate("MasterPasswordDialog", "The Master Password is used to protect site passwords and form data. If you set a Master Password you will be asked to enter it once per session.", nullptr));
        labelCurrentPassword->setText(QCoreApplication::translate("MasterPasswordDialog", "Current Password:", nullptr));
        label_2->setText(QCoreApplication::translate("MasterPasswordDialog", "New Password:", nullptr));
        label_3->setText(QCoreApplication::translate("MasterPasswordDialog", "Confirm Password:", nullptr));
        label_5->setText(QCoreApplication::translate("MasterPasswordDialog", "<b>Note:</b> The Master Password is not resettable. Do not forget it, please.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MasterPasswordDialog: public Ui_MasterPasswordDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MASTERPASSWORDDIALOG_H
