/********************************************************************************
** Form generated from reading UI file 'downloaditem.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOWNLOADITEM_H
#define UI_DOWNLOADITEM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QWidget>
#include "clickablelabel.h"
#include "squeezelabelv2.h"

QT_BEGIN_NAMESPACE

class Ui_DownloadItem
{
public:
    QGridLayout *gridLayout;
    QLabel *fileIcon;
    SqueezeLabelV2 *downloadInfo;
    SqueezeLabelV2 *fileName;
    QFrame *frame;
    QHBoxLayout *progressFrame;
    QProgressBar *progressBar;
    ClickableLabel *pauseResumeButton;
    ClickableLabel *cancelButton;

    void setupUi(QWidget *DownloadItem)
    {
        if (DownloadItem->objectName().isEmpty())
            DownloadItem->setObjectName("DownloadItem");
        DownloadItem->resize(480, 73);
        gridLayout = new QGridLayout(DownloadItem);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(-1, 2, -1, 2);
        fileIcon = new QLabel(DownloadItem);
        fileIcon->setObjectName("fileIcon");
        fileIcon->setMaximumSize(QSize(30, 50));
        fileIcon->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(fileIcon, 0, 0, 3, 1);

        downloadInfo = new SqueezeLabelV2(DownloadItem);
        downloadInfo->setObjectName("downloadInfo");
        downloadInfo->setText(QString::fromUtf8("Remaining 26 minutes - 339MB of 693 MB (350kB/s)"));

        gridLayout->addWidget(downloadInfo, 2, 1, 1, 2);

        fileName = new SqueezeLabelV2(DownloadItem);
        fileName->setObjectName("fileName");
        fileName->setText(QString::fromUtf8("A Clockwork Orange.avi"));

        gridLayout->addWidget(fileName, 0, 1, 1, 2);

        frame = new QFrame(DownloadItem);
        frame->setObjectName("frame");
        frame->setMaximumSize(QSize(16777215, 20));
        progressFrame = new QHBoxLayout(frame);
        progressFrame->setObjectName("progressFrame");
        progressFrame->setContentsMargins(0, 0, 0, 0);
        progressBar = new QProgressBar(frame);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);
        progressBar->setValue(0);
        progressBar->setTextVisible(false);

        progressFrame->addWidget(progressBar);

        pauseResumeButton = new ClickableLabel(frame);
        pauseResumeButton->setObjectName("pauseResumeButton");

        progressFrame->addWidget(pauseResumeButton);

        cancelButton = new ClickableLabel(frame);
        cancelButton->setObjectName("cancelButton");

        progressFrame->addWidget(cancelButton);


        gridLayout->addWidget(frame, 1, 1, 1, 2);


        retranslateUi(DownloadItem);

        QMetaObject::connectSlotsByName(DownloadItem);
    } // setupUi

    void retranslateUi(QWidget *DownloadItem)
    {
        fileIcon->setText(QString());
        pauseResumeButton->setText(QString());
        cancelButton->setText(QString());
        (void)DownloadItem;
    } // retranslateUi

};

namespace Ui {
    class DownloadItem: public Ui_DownloadItem {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DOWNLOADITEM_H
