/********************************************************************************
** Form generated from reading UI file 'iconchooser.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ICONCHOOSER_H
#define UI_ICONCHOOSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_IconChooser
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QPushButton *chooseFile;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QLineEdit *siteUrl;
    QFrame *line;
    QListWidget *iconList;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *IconChooser)
    {
        if (IconChooser->objectName().isEmpty())
            IconChooser->setObjectName("IconChooser");
        IconChooser->resize(388, 326);
        verticalLayout = new QVBoxLayout(IconChooser);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(IconChooser);
        groupBox->setObjectName("groupBox");
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, -1, 0);
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        chooseFile = new QPushButton(groupBox);
        chooseFile->setObjectName("chooseFile");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(chooseFile->sizePolicy().hasHeightForWidth());
        chooseFile->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(chooseFile);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(IconChooser);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_2 = new QHBoxLayout(groupBox_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, -1, -1, 0);
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        siteUrl = new QLineEdit(groupBox_2);
        siteUrl->setObjectName("siteUrl");

        horizontalLayout_2->addWidget(siteUrl);


        verticalLayout->addWidget(groupBox_2);

        line = new QFrame(IconChooser);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        iconList = new QListWidget(IconChooser);
        iconList->setObjectName("iconList");
        iconList->setMovement(QListView::Static);
        iconList->setResizeMode(QListView::Adjust);
        iconList->setViewMode(QListView::IconMode);

        verticalLayout->addWidget(iconList);

        buttonBox = new QDialogButtonBox(IconChooser);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(IconChooser);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, IconChooser, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, IconChooser, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(IconChooser);
    } // setupUi

    void retranslateUi(QDialog *IconChooser)
    {
        IconChooser->setWindowTitle(QCoreApplication::translate("IconChooser", "Choose icon...", nullptr));
        groupBox->setTitle(QCoreApplication::translate("IconChooser", "From file", nullptr));
        label->setText(QCoreApplication::translate("IconChooser", "Image (.png, .jpg, .jpeg, .gif)", nullptr));
        chooseFile->setText(QCoreApplication::translate("IconChooser", "Choose file...", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("IconChooser", "From database", nullptr));
        label_3->setText(QCoreApplication::translate("IconChooser", "Site Url:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IconChooser: public Ui_IconChooser {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ICONCHOOSER_H
