/********************************************************************************
** Form generated from reading UI file 'siteinfowidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SITEINFOWIDGET_H
#define UI_SITEINFOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SiteInfoWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QFrame *frame;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *protocolHandlerLabel;
    QPushButton *protocolHandlerButton;
    QLabel *historyLabel;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushButton;
    QLabel *secureLabel;
    QFrame *protocolHandlerLine;
    QFrame *line_2;
    QFrame *line;
    QLabel *titleLabel;
    QLabel *historyIcon;
    QLabel *secureIcon;
    QLabel *secureDescriptionLabel;

    void setupUi(QWidget *SiteInfoWidget)
    {
        if (SiteInfoWidget->objectName().isEmpty())
            SiteInfoWidget->setObjectName("SiteInfoWidget");
        SiteInfoWidget->resize(123, 198);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SiteInfoWidget->sizePolicy().hasHeightForWidth());
        SiteInfoWidget->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(SiteInfoWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        frame = new QFrame(SiteInfoWidget);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        gridLayout = new QGridLayout(frame);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(-1, -1, 15, -1);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        protocolHandlerLabel = new QLabel(frame);
        protocolHandlerLabel->setObjectName("protocolHandlerLabel");

        horizontalLayout_3->addWidget(protocolHandlerLabel);

        protocolHandlerButton = new QPushButton(frame);
        protocolHandlerButton->setObjectName("protocolHandlerButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(protocolHandlerButton->sizePolicy().hasHeightForWidth());
        protocolHandlerButton->setSizePolicy(sizePolicy1);

        horizontalLayout_3->addWidget(protocolHandlerButton);


        gridLayout->addLayout(horizontalLayout_3, 6, 0, 1, 3);

        historyLabel = new QLabel(frame);
        historyLabel->setObjectName("historyLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(historyLabel->sizePolicy().hasHeightForWidth());
        historyLabel->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(historyLabel, 4, 2, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(10, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pushButton = new QPushButton(frame);
        pushButton->setObjectName("pushButton");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(pushButton->sizePolicy().hasHeightForWidth());
        pushButton->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(pushButton);


        gridLayout->addLayout(horizontalLayout_2, 9, 0, 1, 3);

        secureLabel = new QLabel(frame);
        secureLabel->setObjectName("secureLabel");
        sizePolicy2.setHeightForWidth(secureLabel->sizePolicy().hasHeightForWidth());
        secureLabel->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(secureLabel, 2, 2, 1, 1);

        protocolHandlerLine = new QFrame(frame);
        protocolHandlerLine->setObjectName("protocolHandlerLine");
        protocolHandlerLine->setFrameShape(QFrame::Shape::HLine);
        protocolHandlerLine->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(protocolHandlerLine, 5, 0, 1, 3);

        line_2 = new QFrame(frame);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 1, 0, 1, 3);

        line = new QFrame(frame);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 8, 0, 1, 3);

        titleLabel = new QLabel(frame);
        titleLabel->setObjectName("titleLabel");
        titleLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(titleLabel, 0, 0, 1, 3);

        historyIcon = new QLabel(frame);
        historyIcon->setObjectName("historyIcon");

        gridLayout->addWidget(historyIcon, 4, 0, 1, 1);

        secureIcon = new QLabel(frame);
        secureIcon->setObjectName("secureIcon");

        gridLayout->addWidget(secureIcon, 2, 0, 1, 1);

        secureDescriptionLabel = new QLabel(frame);
        secureDescriptionLabel->setObjectName("secureDescriptionLabel");

        gridLayout->addWidget(secureDescriptionLabel, 3, 2, 1, 1);


        horizontalLayout->addWidget(frame);


        retranslateUi(SiteInfoWidget);

        QMetaObject::connectSlotsByName(SiteInfoWidget);
    } // setupUi

    void retranslateUi(QWidget *SiteInfoWidget)
    {
        pushButton->setText(QCoreApplication::translate("SiteInfoWidget", "More...", nullptr));
        (void)SiteInfoWidget;
    } // retranslateUi

};

namespace Ui {
    class SiteInfoWidget: public Ui_SiteInfoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SITEINFOWIDGET_H
