/********************************************************************************
** Form generated from reading UI file 'sbi_networkicondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SBI_NETWORKICONDIALOG_H
#define UI_SBI_NETWORKICONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "sbi_proxywidget.h"

QT_BEGIN_NAMESPACE

class Ui_SBI_NetworkIconDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *comboBox;
    QToolButton *addButton;
    QToolButton *removeButton;
    QGroupBox *proxyBox;
    QVBoxLayout *verticalLayout;
    QLabel *noProxiesLabel;
    SBI_ProxyWidget *proxyWidget;
    QHBoxLayout *horizontalLayout_2;
    QDialogButtonBox *proxyButtonBox;
    QLabel *label_2;
    QDialogButtonBox *closeButton;

    void setupUi(QWidget *SBI_NetworkIconDialog)
    {
        if (SBI_NetworkIconDialog->objectName().isEmpty())
            SBI_NetworkIconDialog->setObjectName("SBI_NetworkIconDialog");
        SBI_NetworkIconDialog->resize(520, 390);
        verticalLayout_2 = new QVBoxLayout(SBI_NetworkIconDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SBI_NetworkIconDialog);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);

        comboBox = new QComboBox(SBI_NetworkIconDialog);
        comboBox->setObjectName("comboBox");

        horizontalLayout->addWidget(comboBox);

        addButton = new QToolButton(SBI_NetworkIconDialog);
        addButton->setObjectName("addButton");

        horizontalLayout->addWidget(addButton);

        removeButton = new QToolButton(SBI_NetworkIconDialog);
        removeButton->setObjectName("removeButton");

        horizontalLayout->addWidget(removeButton);


        verticalLayout_2->addLayout(horizontalLayout);

        proxyBox = new QGroupBox(SBI_NetworkIconDialog);
        proxyBox->setObjectName("proxyBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(proxyBox->sizePolicy().hasHeightForWidth());
        proxyBox->setSizePolicy(sizePolicy1);
        verticalLayout = new QVBoxLayout(proxyBox);
        verticalLayout->setObjectName("verticalLayout");
        noProxiesLabel = new QLabel(proxyBox);
        noProxiesLabel->setObjectName("noProxiesLabel");
        sizePolicy1.setHeightForWidth(noProxiesLabel->sizePolicy().hasHeightForWidth());
        noProxiesLabel->setSizePolicy(sizePolicy1);
        noProxiesLabel->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(noProxiesLabel);

        proxyWidget = new SBI_ProxyWidget(proxyBox);
        proxyWidget->setObjectName("proxyWidget");
        sizePolicy1.setHeightForWidth(proxyWidget->sizePolicy().hasHeightForWidth());
        proxyWidget->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(proxyWidget);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        proxyButtonBox = new QDialogButtonBox(proxyBox);
        proxyButtonBox->setObjectName("proxyButtonBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(proxyButtonBox->sizePolicy().hasHeightForWidth());
        proxyButtonBox->setSizePolicy(sizePolicy2);
        proxyButtonBox->setStandardButtons(QDialogButtonBox::Save);

        horizontalLayout_2->addWidget(proxyButtonBox);

        label_2 = new QLabel(proxyBox);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(proxyBox);

        closeButton = new QDialogButtonBox(SBI_NetworkIconDialog);
        closeButton->setObjectName("closeButton");
        closeButton->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout_2->addWidget(closeButton);


        retranslateUi(SBI_NetworkIconDialog);

        QMetaObject::connectSlotsByName(SBI_NetworkIconDialog);
    } // setupUi

    void retranslateUi(QWidget *SBI_NetworkIconDialog)
    {
        SBI_NetworkIconDialog->setWindowTitle(QCoreApplication::translate("SBI_NetworkIconDialog", "Proxy Manager", nullptr));
        label->setText(QCoreApplication::translate("SBI_NetworkIconDialog", "Select proxy: ", nullptr));
#if QT_CONFIG(tooltip)
        addButton->setToolTip(QCoreApplication::translate("SBI_NetworkIconDialog", "Add proxy", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        removeButton->setToolTip(QCoreApplication::translate("SBI_NetworkIconDialog", "Remove proxy", nullptr));
#endif // QT_CONFIG(tooltip)
        noProxiesLabel->setText(QCoreApplication::translate("SBI_NetworkIconDialog", "No proxies. You can add proxy by clicking on <b>Add</b> button.", nullptr));
        label_2->setText(QCoreApplication::translate("SBI_NetworkIconDialog", "All changes must be saved with <b>Save</b> button.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SBI_NetworkIconDialog: public Ui_SBI_NetworkIconDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SBI_NETWORKICONDIALOG_H
