/********************************************************************************
** Form generated from reading UI file 'mousegesturessettingsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUSEGESTURESSETTINGSDIALOG_H
#define UI_MOUSEGESTURESSETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_MouseGesturesSettingsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *label_2;
    QLabel *label;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_3;
    QFormLayout *formLayout;
    QLabel *label_22;
    QComboBox *mouseButtonComboBox;
    QLabel *label_23;
    QCheckBox *enableRockerNavigation;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_17;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QLabel *label_10;
    QLabel *label_4;
    QLabel *label_12;
    QLabel *label_5;
    QLabel *label_13;
    QLabel *label_8;
    QLabel *label_7;
    QLabel *label_15;
    QLabel *label_6;
    QLabel *label_9;
    QLabel *label_19;
    QLabel *label_14;
    QLabel *label_16;
    QLabel *label_20;
    QLabel *label_21;
    QLabel *label_18;
    QLabel *label_11;
    QLabel *label_24;
    QLabel *label_25;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *licenseButton;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *MouseGesturesSettingsDialog)
    {
        if (MouseGesturesSettingsDialog->objectName().isEmpty())
            MouseGesturesSettingsDialog->setObjectName("MouseGesturesSettingsDialog");
        MouseGesturesSettingsDialog->resize(502, 433);
        verticalLayout = new QVBoxLayout(MouseGesturesSettingsDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label_2 = new QLabel(MouseGesturesSettingsDialog);
        label_2->setObjectName("label_2");
        label_2->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/icon.png")));

        horizontalLayout->addWidget(label_2);

        label = new QLabel(MouseGesturesSettingsDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(-1, 10, -1, 10);
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_22 = new QLabel(MouseGesturesSettingsDialog);
        label_22->setObjectName("label_22");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_22);

        mouseButtonComboBox = new QComboBox(MouseGesturesSettingsDialog);
        mouseButtonComboBox->addItem(QString());
        mouseButtonComboBox->addItem(QString());
        mouseButtonComboBox->addItem(QString());
        mouseButtonComboBox->setObjectName("mouseButtonComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, mouseButtonComboBox);

        label_23 = new QLabel(MouseGesturesSettingsDialog);
        label_23->setObjectName("label_23");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_23);

        enableRockerNavigation = new QCheckBox(MouseGesturesSettingsDialog);
        enableRockerNavigation->setObjectName("enableRockerNavigation");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, enableRockerNavigation);


        horizontalLayout_3->addLayout(formLayout);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_3);

        label_17 = new QLabel(MouseGesturesSettingsDialog);
        label_17->setObjectName("label_17");
        label_17->setAlignment(Qt::AlignCenter);
        label_17->setWordWrap(true);

        verticalLayout->addWidget(label_17);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(20, -1, 20, -1);
        label_3 = new QLabel(MouseGesturesSettingsDialog);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);
        label_3->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/up.gif")));

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        label_10 = new QLabel(MouseGesturesSettingsDialog);
        label_10->setObjectName("label_10");

        gridLayout->addWidget(label_10, 0, 1, 1, 1);

        label_4 = new QLabel(MouseGesturesSettingsDialog);
        label_4->setObjectName("label_4");
        label_4->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/down.gif")));

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        label_12 = new QLabel(MouseGesturesSettingsDialog);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 1, 1, 1, 1);

        label_5 = new QLabel(MouseGesturesSettingsDialog);
        label_5->setObjectName("label_5");
        label_5->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/left.gif")));

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        label_13 = new QLabel(MouseGesturesSettingsDialog);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 2, 1, 1, 1);

        label_8 = new QLabel(MouseGesturesSettingsDialog);
        label_8->setObjectName("label_8");
        sizePolicy.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy);
        label_8->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/up-down.gif")));

        gridLayout->addWidget(label_8, 0, 2, 1, 1);

        label_7 = new QLabel(MouseGesturesSettingsDialog);
        label_7->setObjectName("label_7");
        label_7->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/down-right.gif")));

        gridLayout->addWidget(label_7, 1, 2, 1, 1);

        label_15 = new QLabel(MouseGesturesSettingsDialog);
        label_15->setObjectName("label_15");

        gridLayout->addWidget(label_15, 1, 3, 1, 1);

        label_6 = new QLabel(MouseGesturesSettingsDialog);
        label_6->setObjectName("label_6");
        label_6->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/right.gif")));

        gridLayout->addWidget(label_6, 2, 2, 1, 1);

        label_9 = new QLabel(MouseGesturesSettingsDialog);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 2, 3, 1, 1);

        label_19 = new QLabel(MouseGesturesSettingsDialog);
        label_19->setObjectName("label_19");

        gridLayout->addWidget(label_19, 3, 1, 1, 1);

        label_14 = new QLabel(MouseGesturesSettingsDialog);
        label_14->setObjectName("label_14");
        label_14->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/down-left.gif")));

        gridLayout->addWidget(label_14, 4, 0, 1, 1);

        label_16 = new QLabel(MouseGesturesSettingsDialog);
        label_16->setObjectName("label_16");

        gridLayout->addWidget(label_16, 4, 1, 1, 1);

        label_20 = new QLabel(MouseGesturesSettingsDialog);
        label_20->setObjectName("label_20");
        label_20->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/up-right.gif")));

        gridLayout->addWidget(label_20, 3, 2, 1, 1);

        label_21 = new QLabel(MouseGesturesSettingsDialog);
        label_21->setObjectName("label_21");

        gridLayout->addWidget(label_21, 3, 3, 1, 1);

        label_18 = new QLabel(MouseGesturesSettingsDialog);
        label_18->setObjectName("label_18");
        label_18->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/up-left.gif")));

        gridLayout->addWidget(label_18, 3, 0, 1, 1);

        label_11 = new QLabel(MouseGesturesSettingsDialog);
        label_11->setObjectName("label_11");

        gridLayout->addWidget(label_11, 0, 3, 1, 1);

        label_24 = new QLabel(MouseGesturesSettingsDialog);
        label_24->setObjectName("label_24");
        label_24->setPixmap(QPixmap(QString::fromUtf8(":/mousegestures/data/down-up.gif")));

        gridLayout->addWidget(label_24, 4, 2, 1, 1);

        label_25 = new QLabel(MouseGesturesSettingsDialog);
        label_25->setObjectName("label_25");

        gridLayout->addWidget(label_25, 4, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        licenseButton = new QPushButton(MouseGesturesSettingsDialog);
        licenseButton->setObjectName("licenseButton");

        horizontalLayout_2->addWidget(licenseButton);

        buttonBox = new QDialogButtonBox(MouseGesturesSettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_2->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(MouseGesturesSettingsDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, MouseGesturesSettingsDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, MouseGesturesSettingsDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(MouseGesturesSettingsDialog);
    } // setupUi

    void retranslateUi(QDialog *MouseGesturesSettingsDialog)
    {
        MouseGesturesSettingsDialog->setWindowTitle(QCoreApplication::translate("MouseGesturesSettingsDialog", "Mouse Gestures", nullptr));
        label->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<h1>Mouse Gestures</h1>", nullptr));
        label_22->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "Mouse button:", nullptr));
        mouseButtonComboBox->setItemText(0, QCoreApplication::translate("MouseGesturesSettingsDialog", "Middle button", nullptr));
        mouseButtonComboBox->setItemText(1, QCoreApplication::translate("MouseGesturesSettingsDialog", "Right button", nullptr));
        mouseButtonComboBox->setItemText(2, QCoreApplication::translate("MouseGesturesSettingsDialog", "Disabled", nullptr));

        label_23->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "Rocker Navigation:", nullptr));
        enableRockerNavigation->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "Enable Rocker Navigation", nullptr));
        label_17->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "Press and hold the mouse button and move your mouse in the indicated directions.", nullptr));
        label_10->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Stop</b><br/>Stop loading page", nullptr));
        label_12->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>New tab</b><br/>Open new tab", nullptr));
        label_13->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Back</b><br/>Go back in history", nullptr));
        label_15->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Close tab</b><br/>Close current tab", nullptr));
        label_9->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Forward</b><br/>Go forward in history", nullptr));
        label_19->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Previous tab</b><br/>Switch to previous tab", nullptr));
        label_16->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Home</b><br/>Go to homepage", nullptr));
        label_21->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Next tab</b><br/>Switch to next tab", nullptr));
        label_11->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Reload</b><br/>Reload page", nullptr));
        label_25->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "<b>Duplicate</b><br/>Duplicate current tab", nullptr));
        licenseButton->setText(QCoreApplication::translate("MouseGesturesSettingsDialog", "License", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MouseGesturesSettingsDialog: public Ui_MouseGesturesSettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MOUSEGESTURESSETTINGSDIALOG_H
