/********************************************************************************
** Form generated from reading UI file 'sitesettingsbrowsedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SITESETTINGSBROWSEDIALOG_H
#define UI_SITESETTINGSBROWSEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SiteSettingsBrowseDialog
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *urlEdit;
    QComboBox *urlComboBox;
    QLabel *nameLabel;
    QPushButton *createButton;
    QTreeWidget *treeWidget;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer_2;
    QPushButton *askButton;
    QPushButton *allowButton;
    QPushButton *denyButton;
    QPushButton *defaultButton;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SiteSettingsBrowseDialog)
    {
        if (SiteSettingsBrowseDialog->objectName().isEmpty())
            SiteSettingsBrowseDialog->setObjectName("SiteSettingsBrowseDialog");
        SiteSettingsBrowseDialog->resize(483, 332);
        gridLayout = new QGridLayout(SiteSettingsBrowseDialog);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SiteSettingsBrowseDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        urlEdit = new QLineEdit(SiteSettingsBrowseDialog);
        urlEdit->setObjectName("urlEdit");
        urlEdit->setInputMethodHints(Qt::InputMethodHint::ImhNoAutoUppercase|Qt::InputMethodHint::ImhUrlCharactersOnly);

        horizontalLayout->addWidget(urlEdit);

        urlComboBox = new QComboBox(SiteSettingsBrowseDialog);
        urlComboBox->setObjectName("urlComboBox");

        horizontalLayout->addWidget(urlComboBox);


        gridLayout->addLayout(horizontalLayout, 2, 0, 1, 1);

        nameLabel = new QLabel(SiteSettingsBrowseDialog);
        nameLabel->setObjectName("nameLabel");

        gridLayout->addWidget(nameLabel, 0, 0, 1, 1);

        createButton = new QPushButton(SiteSettingsBrowseDialog);
        createButton->setObjectName("createButton");

        gridLayout->addWidget(createButton, 2, 1, 1, 1);

        treeWidget = new QTreeWidget(SiteSettingsBrowseDialog);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setIndentation(0);
        treeWidget->setSortingEnabled(true);
        treeWidget->setAllColumnsShowFocus(true);

        gridLayout->addWidget(treeWidget, 3, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer_2 = new QSpacerItem(20, 50, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_2);

        askButton = new QPushButton(SiteSettingsBrowseDialog);
        askButton->setObjectName("askButton");

        verticalLayout_2->addWidget(askButton);

        allowButton = new QPushButton(SiteSettingsBrowseDialog);
        allowButton->setObjectName("allowButton");

        verticalLayout_2->addWidget(allowButton);

        denyButton = new QPushButton(SiteSettingsBrowseDialog);
        denyButton->setObjectName("denyButton");

        verticalLayout_2->addWidget(denyButton);

        defaultButton = new QPushButton(SiteSettingsBrowseDialog);
        defaultButton->setObjectName("defaultButton");

        verticalLayout_2->addWidget(defaultButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout_2, 3, 1, 1, 1);

        buttonBox = new QDialogButtonBox(SiteSettingsBrowseDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 2);


        retranslateUi(SiteSettingsBrowseDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SiteSettingsBrowseDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SiteSettingsBrowseDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SiteSettingsBrowseDialog);
    } // setupUi

    void retranslateUi(QDialog *SiteSettingsBrowseDialog)
    {
        SiteSettingsBrowseDialog->setWindowTitle(QCoreApplication::translate("SiteSettingsBrowseDialog", "Site Permissions", nullptr));
        label->setText(QCoreApplication::translate("SiteSettingsBrowseDialog", "Url:", nullptr));
        urlEdit->setPlaceholderText(QCoreApplication::translate("SiteSettingsBrowseDialog", "https://kde.org", nullptr));
        nameLabel->setText(QString());
        createButton->setText(QCoreApplication::translate("SiteSettingsBrowseDialog", "Set", "Add or Modify"));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("SiteSettingsBrowseDialog", "Behaviour", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("SiteSettingsBrowseDialog", "Site", nullptr));
        askButton->setText(QCoreApplication::translate("SiteSettingsBrowseDialog", "Ask", nullptr));
        allowButton->setText(QCoreApplication::translate("SiteSettingsBrowseDialog", "Allow", nullptr));
        denyButton->setText(QCoreApplication::translate("SiteSettingsBrowseDialog", "Deny", nullptr));
        defaultButton->setText(QCoreApplication::translate("SiteSettingsBrowseDialog", "Default", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SiteSettingsBrowseDialog: public Ui_SiteSettingsBrowseDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SITESETTINGSBROWSEDIALOG_H
