/********************************************************************************
** Form generated from reading UI file 'certificatemanager.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CERTIFICATEMANAGER_H
#define UI_CERTIFICATEMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CertificateManager
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QPushButton *add;
    QPushButton *remove;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QListWidget *listWidget;
    QLabel *warningLabel;

    void setupUi(QDialog *CertificateManager)
    {
        if (CertificateManager->objectName().isEmpty())
            CertificateManager->setObjectName("CertificateManager");
        CertificateManager->resize(415, 225);
        gridLayout = new QGridLayout(CertificateManager);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        add = new QPushButton(CertificateManager);
        add->setObjectName("add");

        verticalLayout->addWidget(add);

        remove = new QPushButton(CertificateManager);
        remove->setObjectName("remove");

        verticalLayout->addWidget(remove);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 0, 1, 1, 1);

        buttonBox = new QDialogButtonBox(CertificateManager);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 2);

        listWidget = new QListWidget(CertificateManager);
        listWidget->setObjectName("listWidget");

        gridLayout->addWidget(listWidget, 0, 0, 1, 1);

        warningLabel = new QLabel(CertificateManager);
        warningLabel->setObjectName("warningLabel");
        QFont font;
        font.setItalic(true);
        warningLabel->setFont(font);

        gridLayout->addWidget(warningLabel, 1, 0, 1, 1);


        retranslateUi(CertificateManager);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CertificateManager, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CertificateManager, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CertificateManager);
    } // setupUi

    void retranslateUi(QDialog *CertificateManager)
    {
        CertificateManager->setWindowTitle(QCoreApplication::translate("CertificateManager", "Certificate exception manager", nullptr));
        add->setText(QCoreApplication::translate("CertificateManager", "Add", nullptr));
        remove->setText(QCoreApplication::translate("CertificateManager", "Remove", nullptr));
        warningLabel->setText(QCoreApplication::translate("CertificateManager", "Removing an entry requires a restart", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CertificateManager: public Ui_CertificateManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CERTIFICATEMANAGER_H
